#!/bin/sh

#       Copyright 2000 BEA Systems, Inc.
#       THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF
#       BEA Systems, Inc.
#       The copyright notice above does not evidence any
#       actual or intended publication of such source code. 

#ident	"@(#)MB/install.sh	$Revision: 1.12.2.47 $"
#################################################
# GENERIC FUNCTIONS USED FOR INSTALLATION - DO NOT CHANGE
#
# ckfuncs:  Installation functions that mimic SVR4 ck* utilities
#

ckitem()
{

	unset QOPT
	unset LABEL
	unset DEFAULT
	unset HELP
	unset INVIS
	unset ERROR
	unset PROMPT
	unset PROMPTSUF
	unset REALPROMPT
	unset MENU

	DEFAULTHELP=`cat <<!
        Enter the number of the menu item you wish to select, or the token
        which is associated with the menu item.   Enter ?? to reprint
        the menu.
!`

	DEFAULTERROR=`cat <<!
ERROR:
        Entry does not match any menu selection. Enter the number of the
        menu item you wish to select, or the token which is associated with
        the menu item.  Enter ?? to reprint the menu.
!`
	USAGE="usage: $0"
	OPTIONS="QWunof:l:i:m:d:h:e:p:k:s:"
	# set -- `getopt "$OPTIONS" $*`
	if [ $? != 0 ] ; then
		echo "$USAGE" >&2
		exit 1
	fi

	while [ -n "$1" ] ; do
		case "$1" in
		-Q) QOPT=yes ; shift ;;
		-W) echo "-W not implemented" >&2 ; shift 2 ;;
		-u|-n|-o) echo "$1 not implemented" >&2 ; shift ;;
		-f) echo "-f not implemented" >&2 ; shift 2 ;;
		-l) LABEL="$2" ; shift 2 ;;
		-i) INVIS="$INVIS $2" ; shift 2 ;;
		-m) echo "$1 not implemented" >&2 ; shift 2 ;;
		-d) DEFAULT="$2" ; shift 2 ;;
		-h) HELP="        $2" ; shift 2 ;;
		-e) ERROR="ERROR: $2" ; shift 2 ;;
		-p) PROMPT="$2" ; shift 2 ;;
		-k|-s) echo "$1 not implemented" >&2 ; shift 2 ;;
	    	# --) shift ; break ;;
		*) break ;;
		esac
	done

	if [ -n "$QOPT" ] ; then
		PROMPTSUF="[?,??]"
	else
		PROMPTSUF="[?,??,q]"
	fi
	if [ -n "$DEFAULT" ] ; then
		PROMPTSUF="(default: $DEFAULT) $PROMPTSUF"
	fi
	if [ -z "$HELP" ] ; then
		HELP="$DEFAULTHELP"
	fi
	if [ -z "$PROMPT" ] ; then
		PROMPT="Enter selection"
	fi
	if [ -z "$ERROR" ] ; then
		ERROR="$DEFAULTERROR"
	fi
	REALPROMPT="\n$PROMPT $PROMPTSUF: \c"
	n=1
	while [ "$#" -gt 0 ] ; do
		if [ -z "$1" ] ; then
			shift
			continue
		fi
		tok=`echo "$1" | cut -f1`
		text=`echo "$1" | cut -f2`
		len=`expr $tok : ".*"`
		tabs="	"
		if [ "$len" -lt 8 ] ; then
			tabs="		"
		fi
		if [ -n "$INVIS" ] ; then
			for i in $INVIS ; do
				if [ "$i" = "$tok" ] ; then
					break
				fi
			done
			if [ "$i" != "$tok" ] ; then
				MENU="$MENU
  $n	$tok$tabs$text"
			fi
		else
			MENU="$MENU
  $n	$tok$tabs$text"
		fi
		KEYS="$KEYS	$n@$tok"
		n=`expr $n + 1 2>/dev/null`
		shift
	done

	if [ -n "$LABEL" ] ; then
		echo "\n$LABEL" >&2
	fi
	echo "$MENU" >&2

	while true ; do
		good=
		echo "$REALPROMPT" >&2
		read ANSWER
		if [ -z "$ANSWER" ] ; then
			if [ -n "$DEFAULT" ] ; then
				echo "$DEFAULT"
				return 0
			else
				echo "ERROR: Input is required" >&2
				continue
			fi
		fi
		for j in $ANSWER ; do
			case "$j" in
			q)	if [ -z "$QOPT" -a "$ANSWER" = q ] ; then
					echo "q"
					return 3
				fi
				;;
			\?)	echo "$HELP" >&2
				continue 2
				;;
			\?\?)	echo "$MENU" >&2
				continue 2
				;;
			esac
			for i in $KEYS ; do
				num=`echo $i | cut -f1 -d@`
				tok=`echo $i | cut -f2 -d@`
				if [ "$j" = "$num" -o "$j" = "$tok" ] ; then
					good="$good $tok"
					continue 2
				fi
			done
			echo "$ERROR" >&2
			continue 2
		done
		# Get rid of trailing/leading spaces
		good=`echo $good`
		echo "$good"
		return 0
	done
}


ckpath()
{

	unset QOPT
	unset ABSOLUTE
	unset ISDIRECTORY
	unset ISFILE
	unset LABEL
	unset DEFAULT
	unset HELP
	unset ERROR
	unset PROMPT
	unset PROMPTSUF
	unset REALPROMPT

	DEFAULTHELP=`cat <<!
        A pathname is a filename, optionally preceded by parent directories.
!`

	DEFAULTERROR=`cat <<!
ERROR:
        Illegal pathname.
!`

	USAGE="usage: $0"
	OPTIONS="QWalrtwxd:h:e:p:k:s:bcfynoz"
	# set -- `getopt "$OPTIONS" $*`
	if [ $? != 0 ] ; then
		echo "$USAGE" >&2
		exit 1
	fi

	while [ -n "$1" ] ; do
		case "$1" in
		-Q) QOPT=yes ; shift ;;
		-W) echo "-W not implemented" >&2 ; shift 2 ;;
		-a) ABSOLUTE=yes ; shift ;;
		-l|-r|-t|-w|-x) echo "$1 not implemented" >&2 ; shift ;;
		-d) DEFAULT="$2" ; shift 2 ;;
		-h) HELP="        $2" ; shift 2 ;;
		-e) ERROR="ERROR: $2" ; shift 2 ;;
		-p) PROMPT="$2" ; shift 2 ;;
		-k|-s) echo "$1 not implemented" >&2 ; shift 2 ;;
		-b|-c|-n|-o|-z) echo "$1 not implemented" >&2 ; shift ;;
		-f) ISFILE=yes ; shift ;;
		-y) ISDIRECTORY=yes ; shift ;;
	    	# --) shift ; break ;;
		*) break ;;
		esac
	done

	if [ -n "$ISFILE" -a -n "$ISDIRECTORY" ] ; then
		echo "ERROR: mutually exclusive options used (-f, -y)" >&2
		return 4
	fi
	if [ -n "$QOPT" ] ; then
		PROMPTSUF="[?]"
	else
		PROMPTSUF="[?,q]"
	fi
	if [ -n "$DEFAULT" ] ; then
		PROMPTSUF="(default: $DEFAULT) $PROMPTSUF"
	fi
	if [ -z "$HELP" ] ; then
		HELP="$DEFAULTHELP"
		if [ -n "$ABSOLUTE" ] ; then
			HELP="$HELP
        - The pathname must begin with a slash (/)."
		fi
		if [ -n "$ISDIRECTORY" ] ; then
			HELP="$HELP
        - The pathname must specify a directory."
		fi
	fi
	if [ -z "$PROMPT" ] ; then
		if [ -n "$ABSOLUTE" ] ; then
			PROMPT="Enter an absolute pathname"
		else
			PROMPT="Enter a pathname"
		fi
	fi
	if [ -z "$ERROR" ] ; then
		ERROR="$DEFAULTERROR"
		if [ -n "$ABSOLUTE" ] ; then
			ERROR="$ERROR
        - Pathname must begin with a slash (/)."
		fi
		if [ -n "$ISDIRECTORY" ] ; then
			ERROR="$ERROR
        - Pathname must specify a directory."
		fi
	fi
	REALPROMPT="\n$PROMPT $PROMPTSUF: \c"

	while true ; do
		echo "$REALPROMPT" >&2
		read ANSWER
		case "$ANSWER" in
		q)	if [ -z "$QOPT" ] ; then
				echo "q"
				return 3
			fi
			if [ -z "$ABSOLUTE" ] ; then
				if [ -z "$ISDIRECTORY" -o -d "$ANSWER" ] ; then
					echo "$ANSWER"
					return 0
				fi
				if [ -z "$ISFILE" -o -f "$ANSWER" ] ; then
					echo "$ANSWER"
					return 0
				fi
			fi
			;;
		\?)	echo "$HELP" >&2
			continue
			;;
		/*)	if [ -z "$ISDIRECTORY" -o -d "$ANSWER" ] ; then
				echo "$ANSWER"
				return 0
			fi
			if [ -z "$ISFILE" -o -f "$ANSWER" ] ; then
				echo "$ANSWER"
				return 0
			fi
			;;
		"")	if [ -n "$DEFAULT" ] ; then
				echo "$DEFAULT"
				return 0
			fi
			;;
		*)	if [ -z "$ABSOLUTE" ] ; then
				if [ -z "$ISDIRECTORY" -o -d "$ANSWER" ] ; then
					echo "$ANSWER"
					return 0
				fi
				if [ -z "$ISFILE" -o -f "$ANSWER" ] ; then
					echo "$ANSWER"
					return 0
				fi
			fi
			;;
		esac
		echo "$ERROR" >&2
	done
}


ckyorn()
{

	unset QOPT
	unset DEFAULT
	unset HELP
	unset ERROR
	unset PROMPT
	unset PROMPTSUF
	unset REALPROMPT

	DEFAULTHELP=`cat <<!
        Enter y or yes if your answer is yes; n or no if your answer is no.
!`

	DEFAULTERROR=`cat <<!
ERROR: Please enter yes or no.
!`

	USAGE="usage: $0"
	OPTIONS="QWd:h:e:p:k:s:"
	# set -- `getopt "$OPTIONS" $*`
	if [ $? != 0 ] ; then
		echo "$USAGE" >&2
		exit 1
	fi

	while [ -n "$1" ] ; do
		case "$1" in
		-Q) QOPT=yes ; shift ;;
		-W) echo "-W not implemented" >&2 ; shift 2 ;;
		-d) DEFAULT="$2" ; shift 2 ;;
		-h) HELP="        $2" ; shift 2 ;;
		-e) ERROR="ERROR: $2" ; shift 2 ;;
		-p) PROMPT="$2" ; shift 2 ;;
		-k|-s) echo "$1 not implemented" >&2 ; shift 2 ;;
	    	# --) shift ; break ;;
		*) break ;;
		esac
	done

	if [ -n "$QOPT" ] ; then
		PROMPTSUF="[y,n,?]"
	else
		PROMPTSUF="[y,n,?,q]"
	fi
	if [ -n "$DEFAULT" ] ; then
		PROMPTSUF="(default: $DEFAULT) $PROMPTSUF"
	fi
	if [ -z "$HELP" ] ; then
		HELP="$DEFAULTHELP"
	fi
	if [ -z "$PROMPT" ] ; then
		PROMPT="Yes or No"
	fi
	if [ -z "$ERROR" ] ; then
		ERROR="$DEFAULTERROR"
	fi
	REALPROMPT="\n$PROMPT $PROMPTSUF: \c"

	while true ; do
		echo "$REALPROMPT" >&2
		read ANSWER
		case "$ANSWER" in
		q)	if [ -z "$QOPT" ] ; then
				echo "q"
				return 3
			fi
			;;
		\?)	echo "$HELP" >&2
			continue
			;;
		y|yes|Y|YES|n|no|N|NO)
			echo "$ANSWER"
			return 0
			;;
		"")	if [ -n "$DEFAULT" ] ; then
				echo "$DEFAULT"
				return 0
			fi
			;;
		esac
		echo "$ERROR" >&2
	done
}
#
# Mimics the SVR4 version of the function. Put here because it
# is part of an optional package (oam) on SVR4 an may not be installed.
# Also used on the non-SVR4 machines.
#
ckstr()
{

	unset QOPT
	unset REGEXP
	unset LABEL
	unset DEFAULT
	unset HELP
	unset ERROR
	unset PROMPT
	unset PROMPTSUF
	unset REALPROMPT
	unset LENGTH

	DEFAULTHELP=`cat <<!
        Please enter a string.
!`

	DEFAULTERROR=`cat <<!
ERROR:
        Entry does not match available menu selection. Enter the number of the
        menu item you wish to select or the token which is associated with
        the menu item.  Enter ?? to reprint the menu.
!`
	USAGE="usage: $0"
	OPTIONS="QWr:l:d:h:e:p:k:s:"
	# set -- `getopt "$OPTIONS" $*`
	if [ $? != 0 ] ; then
		echo "$USAGE" >&2
		exit 1
	fi

	while [ -n "$1" ] ; do
		case "$1" in
		-Q) QOPT=yes ; shift ;;
		-W) echo "-W not implemented" >&2 ; shift 2 ;;
		-r) REGEXP="$2" ; shift 2 ;;
		-l) LENGTH="$2" ; shift 2 ;;
		-d) DEFAULT="$2" ; shift 2 ;;
		-h) HELP="        $2" ; shift 2 ;;
		-e) ERROR="ERROR: $2" ; shift 2 ;;
		-p) PROMPT="$2" ; shift 2 ;;
		-k|-s) echo "$1 not implemented" >&2 ; shift 2 ;;
	    	# --) shift ; break ;;
		*) break ;;
		esac
	done

	if [ -n "$QOPT" ] ; then
		PROMPTSUF="[?]"
	else
		PROMPTSUF="[?,q]"
	fi
	if [ -n "$DEFAULT" ] ; then
		PROMPTSUF="(default: $DEFAULT) $PROMPTSUF"
	fi
	if [ -z "$HELP" ] ; then
		HELP="$DEFAULTHELP"
		if [ -n "$LENGTH" ] ; then
			HELP="$HELP
        - containing no more than $LENGTH characters"
		fi
		if [ -n "$REGEXP" ] ; then
			HELP="$HELP
        - matching the pattern $REGEXP"
		else
			HELP="$HELP
        - containing no embedded, leading, or trailing spaces or tabs"
		fi
	fi
	if [ -z "$PROMPT" ] ; then
		PROMPT="Enter selection"
	fi
	if [ -z "$ERROR" ] ; then
		ERROR="$DEFAULTERROR"
	fi
	REALPROMPT="\n$PROMPT $PROMPTSUF: \c"

	while true ; do
		echo "$REALPROMPT" >&2
		read ANSWER
		case "$ANSWER" in
		q)	if [ -z "$QOPT" ] ; then
				echo "q"
				return 3
			fi
			# fall through - might match
			;;
		\?)	echo "$HELP" >&2
			continue
			;;
		"")	if [ -n "$DEFAULT" ] ; then
				echo "$DEFAULT"
				return 0
			fi
			echo "ERROR: Input is required" >&2
			continue
			;;
		esac
		# can't use expr length on Solaris 2.x
		len=`expr "$ANSWER" : '.*'`
		if [ -n "$LENGTH" ] ; then
			if [ "$len" -gt "$LENGTH" ] ; then
				echo "$ERROR" >&2
				continue
			fi
		fi
		if [ -n "$REGEXP" ] ; then
			match=`expr "$ANSWER" : "$REGEXP"`
			if [ "$match" -ne "$len" ] ; then
				echo "$ERROR" >&2
				continue
			fi
		fi
		echo "$ANSWER"
		return 0
	done
}
#
#
# OTHER GENERIC INSTALLATION FUNCTIONS
#

#
# checkSpace: See if enough space is available in $1
# SPACE lists requirements of each class
# Return 0 if enough space, 1 if not enough.
#

checkSpace()
{

	echo "\nDetermining if sufficient space is available ..." >&2

	blks_needed=0
	spacefile=`echo [Ss][Pp][Aa][Cc][Ee]*`

	if [ -f "$spacefile" ] ; then
		for i in $CLASSES ; do
			blks=`grep "^$i	" < $spacefile | cut -d"	" -f2 2>/dev/null`
			if [ -n "$blks" ] ; then
				blks_needed=`expr $blks + $blks_needed 2>/dev/null`
			fi
		done
	fi
	if [ -z "$blks_needed" ] ; then
		echo "ERROR: Can't calculate space requirements" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 1
	fi

	echo "$blks_needed blocks are required" >&2
	blks_avail=`getFreeBlks $1 2>/dev/null`
	if [ -z "$blks_avail" ] ; then
		echo "ERROR: Can't determine available space in $1" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 1
	fi
	echo "$blks_avail blocks are available to $1" >&2
	if [ "$blks_needed" -gt "$blks_avail" ] ; then
		echo "ERROR: Insufficient space in $1; please choose another directory" >&2
		return 1
	fi
	return 0
}


#
# unloadFile: uncompress/cpio file specified by $1 into $2
# Some systems don't report non-0 exit code for cpio failure,
# so assume failure if "errno" appears in output.
#

unloadFile()
{

	if [ -z "$2" -o ! -x "$2" ] ; then
		echo "ERROR: Can't cd to $2" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 1
	fi
	cd $2
	if [ $? -ne 0 ] ; then
		echo "ERROR: Can't cd to $2" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 1
	fi
	tmp=/tmp/BEA2.$$
	> $tmp

	###
	### If processing individual SNA stack abstraction library, 
	### only install library corresponding to selected stack.
	###
	if [ `basename $1` = "SNASTK.Z" -a "$STACKSEL" != "all"  ] ; then 
		echo "\nUnloading $1 ..." >&2
		uncompress < $1 | cpio -ictB "$STACKSEL" 2>/dev/null | xargs rm -f > $tmp 2>&1
		if [ -n "`cat $tmp`" ] ; then
			echo "ERROR: Can't overwrite files in $2" >&2
			echo "Please ensure that $2 is empty and retry the installation" >&2
			doExit 1
		fi
		uncompress < $1 | cpio -vicdumB "$STACKSEL" 2>&1 | tee $tmp
		if [ $? -ne 0 -o -n "`grep -v tperrno $tmp | grep errno`" ] ; then
			echo "ERROR: Can't unload $1 into $2" >&2
			echo "Please ensure that $2 is empty and retry the installation" >&2
			doExit 1
		fi
	else
		echo "\nUnloading $1 ..." >&2
		uncompress < $1 | cpio -ictB 2>/dev/null | xargs rm -f > $tmp 2>&1
		if [ -n "`cat $tmp`" ] ; then
			echo "ERROR: Can't overwrite files in $2" >&2
			echo "Please ensure that $2 is empty and retry the installation" >&2
			doExit 1
		fi
		uncompress < $1 | cpio -vicdumB 2>&1 | tee $tmp
		if [ $? -ne 0 -o -n "`grep -v tperrno $tmp | grep errno`" ] ; then
			echo "ERROR: Can't unload $1 into $2" >&2
			echo "Please ensure that $2 is empty and retry the installation" >&2
			doExit 1
		fi
	fi

	# Try to change group and user id's in case we are running
	# as root
	uid=`id | sed -e 's/uid=//' -e 's/(.*//'`
	gid=`id | sed -e 's/.*gid=//' -e 's/(.*//'`
	uncompress < $1 | cpio -ictB 2>/dev/null | xargs chgrp $gid 2>/dev/null
	uncompress < $1 | cpio -ictB 2>/dev/null | xargs chown $uid 2>/dev/null

	#
	# Some platforms don't change group/owner on directories using the
	# commands above.  Explicitly do it here.
	#
	find . -type d -exec chgrp $gid {} \; 2>/dev/null
	find . -type d -exec chown $uid {} \; 2>/dev/null

	echo "... finished" >&2
	rm -f $tmp
}

#
# doExit: exit install script.
# $1 is exit code, assumed to be non-zero (bad).
# Assumes error message has already been output.
# Also called if 'quit' is chosen.
#

doExit()
{

	rm -f /tmp/BEA.$$ /tmp/BEA1.$$ /tmp/BEA2.$$ /tmp/BEA3.$$

	echo "\nInstallation terminated" >&2

	exit $1

}

#
# dotPKGINFO: dot in PKGINFO file in current directory
#

dotPKGINFO()
{

	pkginfofile=`echo [Pp][Kk][Gg][Ii][Nn][Ff][Oo]*`
	if [ ! -r "$pkginfofile" ] ; then
		echo "ERROR: pkginfo file missing" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 3
	fi
	. ./$pkginfofile >/dev/null 2>&1
	if [ $? -ne 0 ] ; then
		echo "ERROR: Can't dot pkginfo file" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 3
	fi
}


#
# installPkg: install package named $1, located in directory $dir
# Mimics pkgadd
# Returns 0 if ok, otherwise failed
#

installPkg()
{

	pkg=$1
	dir=$2

	cd $2 2>/dev/null
	if [ $? -ne 0 ] ; then
		echo "ERROR: Can't install unknown package <$i>" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 3
	fi

	#
	# Set up environment: dot pkginfo, etc.
	#
	CLASSES=
	dotPKGINFO
	echo "" >&2
	echo "$NAME" >&2
	echo "($ARCH) $VERSION" >&2
	copyrightfile=`echo [Cc][Oo][Pp][Yy][Rr][Ii][Gg][Hh]*`
	if [ -f "$copyrightfile" ] ; then
		cat $copyrightfile >&2
	fi
	#
	# Execute the pre-install function - one should exist for
	# each of the installable packages. The PREINSTALL and 
	# POSTINSTALL variables are set in the installPkgs function.
	# These functions are executed here to tailor the installation 
	# specifically to the package being installed.
	#
	eval $PREINSTALL

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.  We'll 
	# execute POSTINSTALL, then skip the media install via a return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		eval $POSTINSTALL
		echo "\nUpgrade/Re-installation of "$NAME" was successful" >&2
		return 0
	fi

	if [ -z "$INSTALLDIR" -o -z "$CLASSES" ] ; then
		echo "ERROR: Request script failed" >&2
		echo "Please contact customer support for assistance" >&2
		doExit 3
	fi


	#
	# Based on CLASSES, unload files.
	# Class name is the same as file name, except for case, plus
	# .Z suffix and possible version number.
	#
	# NOTE: Do not use ranges ([A-Z][a-z]) in the tr statement, 
	# since its behavior is directly related to the machine's 
	# locale.
	# 
	for i in *.[Zz]* ; do
		class=`echo $i | tr 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' 'abcdefghijklmnopqrstuvwxyz' | sed 's/\.z.*$//'`
		for j in $CLASSES ; do
			if [ "$j" = "$class" ] ; then
				( unloadFile `pwd`/$i $INSTALLDIR ) || exit $?
				break
			fi
		done
	done

	eval $POSTINSTALL

	if [ "$INSTALLMSGSENT" != "yes" ] ; then
		echo "\nInstallation of "$NAME" was successful" >&2
	fi
	return 0
}


#
# installPkgs: install all packages named in PKGS (from promptPkgs)
#

installPkgs()
{
	for PKG in $PKGS ; do
		# Tack on single quotes
		quoted=\'$PKG\'
		# Get real directory name
		dir=`egrep "^PKG=$1$|^PKG=$quoted$" */[Pp][Kk][Gg][Ii][Nn][Ff][Oo]* /dev/null 2>/dev/null | cut -d/ -f1`
		if [ -z "$dir" -o ! -d "$dir" ] ; then
			echo "ERROR: Can't find directory containing package $1" >&2
			echo "Please contact customer support for assistance" >&2
			doExit 3
		fi

		PREINSTALL=preinstall${PKG}
		POSTINSTALL=postinstall${PKG}

		installPkg "$PKG" "$dir" || doExit $?
		cd $STARTDIR
	done
	return 0
}

#
# valDIR: validate the proposed directory, passed in $1
# Return 0 if ok, 1 if bad.
# Pass "yes" in $2 to skip space check.
#

valDIR()
{

	dir=$1
	skipSpaceCk=$2
	created=

	#
	# If directory exists, make sure it's writable, searchable,
	# preferably empty.
	#

	if [ -d "$dir" ] ; then
		if [ ! -w "$dir" ] ; then
			echo "ERROR: $dir is not writable; please choose another directory" >&2
			return 1
		fi
		if [ ! -x "$dir" ] ; then
			echo "ERROR: Can't cd to $dir; please choose another directory" >&2
			return 1
		fi
#		if [ "`ls -a $dir | wc -l`" -ne 2 ] ; then
#			echo "Note that directory $dir is not empty" >&2
#			ANSWER=`ckyorn \
#				-h "This installation may fail if files in this directory\nor its subdirectories can't be overwritten!" \
#				-p "Do you wish to choose another directory"` || doExit $?
#			case "$ANSWER" in
#			y|Y|yes|YES)	return 1
#					;;
#			n|N|no|NO)	;;
#			esac
#		fi

	#
	# No good if it's an existing file
	#

	elif [ -f "$dir" ] ; then
		echo "ERROR: $dir is a file" >&2
		return 1

	#
	# Try to make the directory if it does not exist
	#

	else
		mkdir -p $dir 2>/dev/null
		if [ "$?" -ne 0 ] ; then
			echo "ERROR: Can't create $dir; please choose another directory" >&2
			return 1
		fi
		echo "Creating $dir" >&2
		created=yes
	fi

	#
	# Verify cd; pathname must already be absolute (ckpath)
	#
	(
		cd $dir 2>/dev/null
		rtn=$?
	)

	if [ "$rtn" -ne 0 ] ; then
		echo "ERROR: Can't cd to $dir; please choose another directory" >&2
		return 1
	fi

	#
	# See if there's enough space
	#
	if [ "$skipSpaceCk" != "yes" ] ; then
		checkSpace $dir
		if [ $? -ne 0 ] ; then
			if [ -n "$created" ] ; then
				rm -rf $dir
			fi
			return 1
		fi
	fi

	return 0
}

#
# Prompts the user with the string given, and
# passes back TRUE for an answer of "y", FALSE for "n" and
# quits with an answer of "q." Prompt_User will continue
# to prompt until the user enters y, n or q.
#
Prompt_User()
{
	#
	# prompt until the user gives a valid response.
	#
	ANSWER=
	while [ -z "${ANSWER}" ]; do
	        echo "$1 [y/n/q]: \c" >&2
		read ANSWER
	        #
	        # Act according to the user's response.
	        #
	        case "${ANSWER}" in
	        y) 
			return 0     # TRUE
	        ;;
	        n) 
			return 1     # FALSE
	        ;;
	        q) 
			doExit 0
	        ;;
	        #
	        # An invalid choice was entered, reprompt.
	        #
	        *) ANSWER=
	        ;;
	        esac
	done
}


#
# Prompts the user with the string given, and
# passes back TRUE for an answer of "y" and FALSE for "n".
# Prompt_User_yn will continue to prompt until the user enters y or n.
#
Prompt_User_yn()
{
	#
	# prompt until the user gives a valid response.
	#
	ANSWER=
	while [ -z "${ANSWER}" ]; do
	        echo "$1 [y/n]: \c" >&2
		read ANSWER
	        #
	        # Act according to the user's response.
	        #
	        case "${ANSWER}" in
	        y) 
			return 0     # TRUE
	        ;;
	        n) 
			return 1     # FALSE
	        ;;
	        #
	        # An invalid choice was entered, reprompt.
	        #
	        *) ANSWER=
	        ;;
	        esac
	done
}


#
# Print the available platforms into a readable form.
#
PresentPlatforms()
{
	bldPlatformMenu

	echo "\n$NICEPLATFORMLIST" >&2
}

#
# Determine if the number the user entered exceeds the total 
# number of platforms.
#
ValidPlatformNumber()
{
	if [ "${PLATFORM_NUMBER}" -le "${TOTAL_PLATFORMS}" ]
	then
		#
		# A valid number was entered, return TRUE.
		#
		return 0;
	else
		#
		# An invalid platform number was entered,
		# return FALSE.
		#
		return 1;
	fi
}

#
# Prints an error message.
#
BadPlatformMessage()
{
	echo >&2
	BADPLATFORMMSG="** Invalid entry! Only integer values between 01 and ${TOTAL_PLATFORMS} are legal. **"
	echo $BADPLATFORMMSG >&2
}

#
# Get the user's choice for the installation platform.
#
GetPlatformNumber()
{
	#
	# Get the total number of platforms available.
	#
	TOTAL_PLATFORMS=`echo "$RAWPLATFORMLIST" | wc -l`

	PLATFORM_NUMBER=

	#
	# Build the prompt.
	#
	MSG="Install which platform's files? [01 - ${TOTAL_PLATFORMS}, q to quit, l for list]: \c"

	#
	# Continually prompt until a valid number is entered.
	#
	while [ -z "${PLATFORM_NUMBER}" ]
	do
		echo >&2
		echo $MSG >&2
		read PLATFORM_NUMBER
		#
		# Make sure a platform number between 01 and the
		# total number of platforms was entered. If not,
		# reprompt...
		#
		case "${PLATFORM_NUMBER}" in
		#
		# If a number was entered, check to make sure it doesn't 
		# exceed the total number of platforms available. Want to 
		# the possibility of 00 being entered.
		#
		[1-9] | [0-9][1-9] | [1-9][0-9])
			ValidPlatformNumber && break
			BadPlatformMessage
			PLATFORM_NUMBER=
		;;
		#
		# Allow the user to quit.
		#
		q|Q|quit|Quit|QUIT)
			doExit 1
		;;
		#
		# In the case of a carriage return, reprompt.
		#
		"")
			PLATFORM_NUMBER=
		;;
		#
		# Display the available platforms.
		#
		l)
			PresentPlatforms
			PLATFORM_NUMBER=
		;;
		#
		# Anything other than a number is invalid for
		# sure, reprompt.
		#
		*) 
			BadPlatformMessage
			PLATFORM_NUMBER=
		;;
		esac
	done
}

#
# Convert the number chosen to the platform's directory. 
#
ConvertNumberToDirectory()
{
	#
	# Since we don't have arrays in Bourne Shell, this is sort
	# of a kludge.
	#
	i=1
	#
	# Loop until the number chosen is hit.
	#
	for PLATFORM in `echo $RAWPLATFORMLIST`
	do
		if [ "$i" -eq "${PLATFORM_NUMBER}" ]; then
			break;
		fi
		i=`expr $i + 1`
	done
}

#
# Display the platform information from the platinfo file
# located in the directory chosen. 
#
DisplayChoice()
{
	echo >&2
	echo "** You have chosen to install software for **" >&2
	echo >&2
	#
	# 'platinfo' file may be in upper or lower case.
	#
	if [ -r "${PLATFORM}/PLATINFO" ]; then
		cat ${PLATFORM}/PLATINFO >&2
		echo >&2
	else
		if [ -r "${PLATFORM}/platinfo" ]; then
			cat ${PLATFORM}/platinfo >&2
			echo >&2
		else
			#
			# Should never get in here - a 'platinfo'
			# file should be generated for each platform.
			#
			echo >&2
			echo "** ERROR: No platform information exists \c" >&2
			echo "for this selection. **"  >&2
			doExit 1
		fi
	fi
}	

createSuminfofile()
{
 
	###
	### Accept suffix ($2) in this routine to allow processing of
	### different SUMINFO files for each class.
	###
        suminfofile=`echo [Ss][Uu][Mm][Ii][Nn][Ff][Oo]$2`
 
        #
        # Make sure the file exists.
        #
        if [ ! -f "$suminfofile" ]; then
                echo "WARN: Can't create suminfo file" >&2
                return
        fi
 
        #
        # Put the sum information into the filename passed.
        #
	sumfilename=$1
        rm -f $sumfilename 2>/dev/null
 
        cp -f $suminfofile $sumfilename
 
        if [ $? -ne 0 ] ; then
                echo "WARN: Can't create suminfo file" >&2
                return
        fi
}

#
# Platform specific functions:
# The purpose of these functions is to
# set any environment specific issues for the install shell.
#
#	Define getFreeBlks function
#	Define ARCH environment variable
#	Set PATH
#	Set any path for the dynamic loader/linker
#
envAlpha()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed 1d | awk '{print $4}'
	}
	ARCH=alpha
}

envGeneric()
{
	# used for all platforms
	PATH=:/usr/5bin:/bin:/usr/bin:$PATH
	export PATH
	getFreeBlks() {
		t=$1
		while true ; do
			t1=`df $t 2>/dev/null`
			if [ $? -eq 0 ] ; then
				echo $t1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
				break
			fi
			t=`dirname $t`
		done
	}
	ARCH=generic
}

envHp()
{
	PATH=:/bin:/usr/bin:$PATH
	export PATH
	getFreeBlks() {
		t=$1
		while true ; do
			t1=`df $t 2>/dev/null`
			if [ $? -eq 0 ] ; then
				echo $t1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
				break
			fi
			t=`dirname $t`
		done
	}
	ARCH=9000
	#
	# _TMLDPATH - shared library path if not LD_LIBRARY_PATH
	#
	_TMLDPATH=SHLIB_PATH
}

envIbm()
{
	PATH=:/usr/bin:$PATH
	export PATH
	getFreeBlks() {
		df $1 | awk '{ if (NR==2) printf "%d\n", $3 * 2 }'
	}
	ARCH=rs6000
	#
	# _TMLDPATH - shared library path if not LD_LIBRARY_PATH
	#
	_TMLDPATH=LIBPATH
}

envNcr()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=i386
}

envUnisys()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=i386
}

envPyr()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=MIServer-S
}

envSni()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=mips
}

envTandem()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=mips-S
}

envSco()
{
	PATH=:/bin:/usr/bin:$PATH
	export PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=i386
}

envSun4x()
{
	PATH=:/usr/5bin:/bin:/usr/bin::/usr/ccs/bin:/usr/ucb:$PATH
	export PATH
	getFreeBlks() {
		df -t $1 | sed -e 1d | awk '{print $2}'
	}
	ARCH=sun4
}

envSun5x()
{
	PATH=:/usr/5bin:/bin:/usr/bin:/usr/ucb:/usr/ccs/bin:$PATH
	export PATH
	getFreeBlks() {
		df -t $1 | sed -e 2d -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=sparc
}

envUw()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=i386
}

envDgintl()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[   ]*//' -e 's/ blocks.*//'
	}
	ARCH=i386
}

envDgm88k()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[   ]*//' -e 's/ blocks.*//'
	}
	ARCH=mc88110
}

envSeq()
{
	PATH=:/bin:/usr/bin:$PATH
	export PATH
	getFreeBlks() {
		df $1 | sed -e 's/.*):[ 	]*//' -e 's/ blocks.*//'
	}
	ARCH=sequent
}

envSgi()
{
	PATH=:/bin:/usr/bin/:$PATH
	getFreeBlks() {
		df $1 | sed -e 1d | awk '{print $5}'
	}
	ARCH=sgi
}

# End of generic functions
##########################################
#
#
# APPLICATION SPECIFIC FUNCTIONS
#
#
##########################################

#
# Generate a list of platforms that can be installed by examining the names
# of the directories below us and eliminating non-Unix directories and files.
#
getplatforms()
{
	RAWPLATFORMLIST=`ls -d * 2>/dev/null | sed -e '/autorun.inf/d' -e '/install.sh/d' -e '/inwnt40/d' -e '/alwnt40/d' -e '/inwin95/d' -e '/inwin98/d' -e '/as400/d' -e '/ibmoe/d' -e '/INWNT40/d' -e '/ALWNT40/d' -e '/INWIN95/d' -e '/INWIN98/d' -e '/AS400/d' -e '/IBMOE/d' -e '/INSTALL.SH/d' -e '/AUTORUN.INF/d'`
}

#
# promptComponents: prompt for top level component to install.
# Puts the user in position to install the selected component.
# Returns 0 if ok, otherwise failed.
#

promptComponents()
{

	# Get prompt strings by looking for DESCRIP file in each subdir
	menu1=
	menu2=
	menu3=
	target1=
	target2=
	target3=
	for i in * ; do
		descrip=`echo $i/[Dd][Ee][Ss][Cc][Rr][Ii][Pp]`
		if [ -r "$descrip" ] ; then
			target="`grep '^COMPONENT=' $descrip | sed 's/COMPONENT=//'`"
			targetdesc="`grep '^DESC=' $descrip | sed 's/DESC=//'`"
		else
			continue
		fi

		# target, targetdesc may have quotes, so get rid of them
		target=`echo $target | sed "s/'//g"`
		targetdesc=`echo $targetdesc | sed "s/'//g"`

		# Based on the target, determine how many there are.
		case "$target" in
		servers|security|tps|sna|osi|wlcsdoc)
			menu1="$target	$targetdesc"
			target1="$target"
			;;
		clients)
			menu2="$target	$targetdesc"
			target2="$target"
			;;
		admcon)
			menu3="$target	$targetdesc"
			target3="$target"
			;;
		esac
	done

	ANSWER=`ckitem -l "The following components are available:" \
		-p "Select the one you wish to install" \
		"$menu1" "$menu2" "$menu3"`
	rtn=$?
	if [ $rtn -ne 0 ] ; then
		if [ $rtn -eq 3 ] ; then
			echo "\nInstallation terminated" >&2
			exit 0
		fi
		return $rtn
	fi

	#
	# Directory name may be upper-case, prepare for that here.
	#
	uc_dir=`echo $ANSWER | tr 'abcdefghijklmnopqrstuvwxyz' 'ABCDEFGHIJKLMNOPQRSTUVWXYZ' ` 

	#
	# Check for and go to the directory chosen.
	#
	if [ -d "$ANSWER" ] ; then
		cd $ANSWER
	else
		cd $uc_dir
	fi

	#
	# Remember where we are so we can get back.
	#
	STARTDIR=`pwd`

	return 0
}

#
# promptPkgs: prompt for packages to install
# Mimics pkgadd behavior
# Sets PKGS to list of packages to install.
# Sets ALLPKGS to non-null if all was specified.
# Returns 0 if ok, otherwise failed.
#

promptPkgs()
{

	# Get prompt strings by looking for PKGINFO file in each subdir
	param1=
	param2=
	param3=
	param4=
	pkg1=
	pkg2=
	pkg3=
	pkg4=
	for i in * ; do
		pkginfo=`echo $i/[Pp][Kk][Gg][Ii][Nn][Ff][Oo]*`
		if [ -r "$pkginfo" ] ; then
			pkg="`grep '^PKG=' $pkginfo | sed 's/PKG=//'`"
			pkgname="`grep '^NAME=' $pkginfo | sed 's/NAME=//'`"
		else
			continue
		fi

		# pkg, pkgname may have quotes, so get rid of them
		pkg=`echo $pkg | sed "s/'//g"`
		pkgname=`echo $pkgname | sed "s/'//g"`

		# Based on the pkg, determine how many there are.
		case "$pkg" in
		wletsrv|wletcli|sec128|sec56|tps|sna|osi|admcon|wlcsdoc)
			param1="$pkg	$pkgname"
			pkg1="$pkg"
			;;
		wlecsrv|wleccli)
			param2="$pkg	$pkgname"
			pkg2="$pkg"
			;;
		wlejsrv|wlejcli)
			param3="$pkg	$pkgname"
			pkg3="$pkg"
			;;
		wlej2ee|wlermi)
			param4="$pkg	$pkgname"
			pkg4="$pkg"
			;;
		esac
	done

	ANSWER=`ckitem -l "The following packages are available:" \
		-p "Select the package(s) you wish to install (or 'all' to install\nall packages)" \
		-i all -d all \
		"$param1" "$param2" "$param3" "$param4" "all	all"`
	rtn=$?
	if [ $rtn -ne 0 ] ; then
		if [ $rtn -eq 3 ] ; then
			echo "\nInstallation terminated" >&2
			exit 0
		fi
		return $rtn
	fi

	# If all, go back and get the packages in the same order as presented
	if [ "$ANSWER" = all ] ; then
		ALLPKGS=all
		all=
		for i in "$pkg1" "$pkg2" "$pkg3" "$pkg4" ; do
			all="$all $i"
		done
		ANSWER="`echo $all`"
	fi
	PKGS="$ANSWER"
	return 0
}

#
# promptSNAOpts: prompt for stack support option. 
# 

promptSNAOpts()
{
	STACK1=
	STACK2=
	STACK3=
	STACK4=
	STACK5=
	STACK6=
	STACK7=
	STACK8=
	STACK9=
	STACKALL="all	All Stacks"
	STACKSEL=
	sfx=

        STACKLIBS=`uncompress < SNASTK.Z | cpio -ictB 2>/dev/null`

	for i in $STACKLIBS ; do
		case "$i" in
			lib/libcsxbrx41.so)
				STACK1="brx41	Brixton 4.1"
			;;
			lib/libcsxibm50.so)
				STACK2="ibm50	AIX Comm. Server v5.0"
			;;
			lib/libcsxhp51.sl)
				STACK3="hp51	SNA plus2 v5.1"
			;;
			lib/libcsxhp60.sl)
				STACK4="hp60	SNA plus2 v6.0"
			;;
			lib/libcsxsun91.so)
				STACK5="sun91	SUN Link 9.1"
			;;
			lib/libcsxspx60.so)
				STACK6="spx60	DCL SNAP-IX 6.0"
			;;
			lib/add_new_stack_here)
				STACK7=""
			;;
			lib/add_new_stack_here)
				STACK8=""
			;;
			lib/add_new_stack_here)
				STACK9=""
			;;
			*)
			echo "ERROR: Unidentified stack abstraction library" >&2
			echo "Please contact customer support for assistance" >&2
			;;
		esac
	done
	
	ANSWER=`ckitem -l "The following SNA stack support options are available:" \
		-p "Select an option" \
		-d "All stacks" \
		"$STACK1" "$STACK2" "$STACK3" "$STACK4" "$STACK5" "$STACK6" \
		"$STACK7" "$STACK8" "$STACK9" "$STACKALL"` || doExit $?

	case $MNEMONIC in
		ibm)	sfx=".so"
		;;
		hp)	sfx=".sl"
		;;
		sun5x)	sfx=".so"
		;;
		*)	sfx=".so"
		;;
	esac
	
	if [ $ANSWER = all ] ; then
		STACKSEL="all"
	else
		STACKSEL="lib/libcsx${ANSWER}${sfx}"
	fi
}

#
# promptWEBDIR: prompt for and validate WEBDIR
#

promptWEBDIR()
{

	# Make sure the directory one level above the suggested
	# default exists.
	mkdir $INSTALLDIR/udataobj >/dev/null 2>&1
	while true ; do
	
		ANSWER=`ckpath -a \
			-d "$INSTALLDIR/udataobj/webgui" \
			-p "Directory where BEA Administration Console documents and images are to be\ninstalled" \
			-h "Consult your web server documentation for an appropriate directory"` || doExit $?
	
		# Valuing 2nd parm to valDIR as "yes" causes file 
		# system space check to be skipped.  
		valDIR "$ANSWER" "yes"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done
	# Pick up dir, since it may be different from ANSWER
	WEBDIR=$dir
	export WEBDIR
	DOT=$dir
	echo "\nUsing $WEBDIR as the BEA Administration Console document tree" >&2
}

#
# promptWEBCGIDIR: prompt for and validate WEBCGIDIR
#

promptWEBCGIDIR()
{

	while true ; do
	
		ANSWER=`ckpath -a \
			-d "$WEBDIR/cgi-bin" \
			-p "Directory where BEA Administration Console CGI programs are to be\ninstalled" \
			-h "Consult your web server documentation for an appropriate CGI directory"` || doExit $?
	
		# Valuing 2nd parm to valDIR as "yes" causes file 
		# system space check to be skipped.  
		valDIR "$ANSWER" "yes"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done
	# Pick up dir, since it may be different from ANSWER
	WEBCGIDIR=$dir
	export WEBCGIDIR
	DOT=$dir
	echo "\nUsing $WEBCGIDIR as the BEA Administration Console CGI directory" >&2
}

#
# promptWEBCGIPREFIX: prompt for and validate WEBCGIPREFIX
#

promptWEBCGIPREFIX()
{

	while true ; do
	
		ANSWER=`ckstr \
			-r '/.*[^/]' \
			-d "/cgi-bin" \
			-p "Web server client prefix for CGI directory.  /cgi-bin is a good choice for most web servers." \
			-e "Prefix must start with /, must have at least one additional character, and must not end with /." \
			-h "Consult your web server documentation for an appropriate CGI prefix"` || doExit $?

		if [ "$?" -eq 0 ] ; then
			break
		fi
	done
	WEBCGIPREFIX=$ANSWER
	export WEBCGIPREFIX
	echo "\nUsing $WEBCGIPREFIX as the BEA Administration Console CGI prefix" >&2
}

#
# promptWEBJAVADIR: prompt for and validate WEBJAVADIR
#

promptWEBJAVADIR()
{

	while true ; do
	
		ANSWER=`ckpath -a \
			-d "$WEBDIR/java" \
			-p "Directory where BEA Administration Console java applets are to be\ninstalled" \
			-h "Consult your web server documentation for an appropriate JAVA directory"` || doExit $?
	
		# Valuing 2nd parm to valDIR as "yes" causes file 
		# system space check to be skipped.  
		valDIR "$ANSWER" "yes"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done
	# Pick up dir, since it may be different from ANSWER
	WEBJAVADIR=$dir
	export WEBJAVADIR
	mkdir -p $WEBJAVADIR >/dev/null 2>&1
	mkdir $WEBJAVADIR/snapshot >/dev/null 2>&1
	echo "\nUsing $WEBJAVADIR as the BEA Administration Console document tree" >&2
}

#
# promptLDAPURL: build the URL of the LDAP server & port by prompting for each
# part.  Also prompt for the base object used by the certificate lookup plugin.
#

promptLDAPURL()
{

	HOSTNAME=
	PORTID=
	while true ; do

		HOSTNAME=`ckstr \
			-r '[0-9a-zA-Z].*' \
			-p "Enter fully qualified hostname for URL of the LDAP server system." \
			-h "Entry should use the form 'mynode.mydomain.com'." \
			-e "This entry is required."` || doExit $?

		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	while true ; do

		PORTID=`ckstr \
			-r '[0-9][0-9]*' \
			-p "Enter a port number for the URL of the LDAP server system." \
			-h "Entry must be numeric." \
			-e "This entry is required and must be numeric."` || doExit $?

		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	LDAPURL="$HOSTNAME:$PORTID"
	export LDAPURL
	echo "\nUsing '$LDAPURL' as the URL of the LDAP server/port " >&2

	while true ; do

		LDAPBASEOBJ=`ckstr \
			-r '[0-9a-zA-Z].*' \
			-p "Enter a base object for search in LDAP server." \
			-h "Entry should specified as a distinguished name in string format (eg. o=mydomain.com;e=doe@mydomain.com)." \
			-e "This entry is required."` || doExit $?

		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	LDAPBASEOBJ="$LDAPBASEOBJ"
	export LDAPBASEOBJ
	echo "\nUsing '$LDAPBASEOBJ' as the base object " >&2

}

#
# promptLDAPFILTER: prompt for the location and name of the LDAP filter file
#

promptLDAPFILTER()
{

	LDAPFILTER=
	while true ; do

		LDAPFILTER=`ckstr \
			-r '.*' \
			-d "$INSTALLDIR/udataobj/security/bea_ldap_filter.dat" \
			-p "Location and name of LDAP filter file." \
			-e "This entry is required." \
			-h "Consult your documentation for an appropriate value"` || doExit $?
	
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done
	LDAPFILTER="file://$LDAPFILTER"
	export LDAPFILTER
	echo "\nUsing '$LDAPFILTER' as the location and name of LDAP filter file" >&2
}

#
# promptWLEDIR: prompt for and validate WLEDIR
#

promptWLEDIR()
{

	while true ; do

		ANSWER=`ckpath -a \
			-p "Directory where WebLogic Enterprise files are to be installed" \
			-h "Specify a directory for the WebLogic Enterprise base directory"` || doExit $?

		valDIR "$ANSWER"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done
	# Pick up dir, since it may be different from ANSWER
	INSTALLDIR=$dir
	export INSTALLDIR
	echo "\nUsing $INSTALLDIR as the WebLogic Enterprise base directory" >&2
	# Some files have the "TUXDIR" variable in them, so set it.
	TUXDIR=$INSTALLDIR
	export TUXDIR
}

getTUXDIR()
{

	while true ; do

		ANSWER=`ckpath -a \
			-d "$TUXDIR" \
			-p "Location of existing BEA software installation" \
			-h "Specify an existing software base directory"` || doExit $?

		#
		# libgp.a is installed on every WLE platform.
		#
		if [ ! -f "$ANSWER/lib/libgp.a" ]; then
			echo "\nERROR: $ANSWER doesn't contain a valid BEA installation.\n" >&2
			doExit 1
		fi

		#
		# Depending upon the platform, the shared gp library could
		# be named libgp.sl, libgp.so, libgp.so.65, or libgp.a (on AIX).
		#
		# To prevent the need for the user to re-archive if
		# they choose to revert back to a previous encryption level,
		# create a backup of the libgp.a file as well (assuming the
		# platform is not AIX).
		#
		GPFILENAME=
		GPFILENAMEA=
		for file in `ls $ANSWER/lib/libgp.*`
		do
			case $file in
        		*libgp.sl|*libgp.so*) 
				GPFILENAME=`basename $file`
				;;
			*libgp.a)
				GPFILENAMEA=`basename $file`
				;;
			esac
		done

		# GPFILENAME will be null if the platform is AIX.
		if [ -z "$GPFILENAME" ] ; then
			GPFILENAME=$GPFILENAMEA
		fi

		valDIR "$ANSWER" "yes"

		if [ "$?" -eq 0 ] ; then
			break
		fi

	done
	#
	# Pick up dir, since it may be different from ANSWER
	#
	INSTALLDIR=$dir
	export INSTALLDIR
	export GPFILENAME GPFILENAMEA
	echo "\nUsing $INSTALLDIR as the base directory" >&2
}

promptWLCSDIR()
{

	while true ; do

		ANSWER=`ckpath -a \
			-p "Location of existing BEA WLCS software installation" \
			-h "Specify an existing software base directory"` || doExit $?

		#
		# server/public_html directory is installed on every WLCS platform.
		#
		if [ ! -d "$ANSWER/server/public_html" ]; then
			echo "\nERROR: $ANSWER doesn't contain a valid WLCS installation.\n" >&2
			doExit 1
		fi

		valDIR "$ANSWER" "yes"

		if [ "$?" -eq 0 ] ; then
			break
		fi

	done
	#
	# Pick up dir, since it may be different from ANSWER
	#
	INSTALLDIR=$dir/server/public_html
	TUXDIR=$INSTALLDIR
	export INSTALLDIR TUXDIR
	echo "\nUsing $INSTALLDIR as the installation directory" >&2
}

promptTPSDIR()
{

	while true ; do

		ANSWER=`ckpath -a \
			-p "Directory where TPS files are to be installed" \
			-h "Specify a directory for the TPS base directory"` || doExit $?

		valDIR "$ANSWER"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	#
	# Pick up dir, since it may be different from ANSWER
	#
	INSTALLDIR=$dir
	export INSTALLDIR

	echo "\nUsing $INSTALLDIR as the TPS base directory" >&2
}

promptSNADIR()
{

	while true ; do

		ANSWER=`ckpath -a \
			-p "Directory where SNA files are to be installed" \
			-h "Specify a directory for the SNA base directory"` || doExit $?

		valDIR "$ANSWER"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	#
	# Pick up dir, since it may be different from ANSWER
	#
	INSTALLDIR=$dir
	export INSTALLDIR

	echo "\nUsing $INSTALLDIR as the SNA base directory" >&2
}

promptOSIDIR()
{

	while true ; do

		ANSWER=`ckpath -a \
			-p "Directory where OSI files are to be installed" \
			-h "Specify a directory for the OSI base directory"` || doExit $?

		valDIR "$ANSWER"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	#
	# Pick up dir, since it may be different from ANSWER
	#
	INSTALLDIR=$dir
	export INSTALLDIR

	echo "\nUsing $INSTALLDIR as the OSI base directory" >&2
}

#
# newTUXLocale: set up symbolic links if LANG!=C
# $* is list of full pathnames of candidate C directories
#

newTUXLocale()
{

	iLANG=$LANG

	if [ -z "$iLANG" -o "$iLANG" = C ] ; then
		return
	fi

	# We will be changing the current directory.  Save the name so we can
	# get back to it.

	InstDir=`pwd`

	for i in $* ; do
		dn=`dirname $i 2>/dev/null`
		if [ -z "$dn" -o -d "$dn/$iLANG" ] ; then
			continue
		fi
		echo "\nSetting up additional locale: $dn/$iLANG ..." >&2
		cd $dn
		if [ $? -ne 0 ] ; then
			echo "ERROR: Can't cd to $dn" >&2
			echo "Please contact customer support for assistance" >&2
			doExit 3
		fi
		ln -s C $iLANG
		if [ $? -ne 0 ] ; then
			echo "ERROR: Can't link $dn/C to $dn/$iLANG" >&2
			echo "Please contact customer support for assistance" >&2
			doExit 3
		fi
		echo "... finished" >&2
	done

	# Return to the installation directory so we can continue.

	cd $InstDir
}

#
# beginMsg: Output welcome message.
#

beginMsg()
{
	echo "\n************************************************************" >&2
	echo "*      BEA Systems, Inc. Software Installation System      *" >&2
	echo "*                                                          *" >&2
	echo "*  Please refer to your Installation Guide for details on  *" >&2
	echo "*  how to use this program.                                *" >&2
	echo "************************************************************" >&2
}

#
# createTUXwsvrIni: Create $INSTALLDIR/udataobj/tuxwsvr.ini file for use
# with the tuxwsvr generic web server
#

createTUXwsvrIni()
{

	if [ -d "$INSTALLDIR" -a -d "$WEBDIR" ]
	then
		WINI=$INSTALLDIR/udataobj/tuxwsvr.ini
		echo "# tuxwsvr initialization file." >$WINI
		echo "# Created `date` by BEA software installation program." >>$WINI
		echo "#" >>$WINI
		echo "CGI	$WEBCGIPREFIX	$WEBCGIDIR" >>$WINI
		echo "HTML	/java	$WEBJAVADIR" >>$WINI
		echo "HTML	/doc	${DOCDIR:-$INSTALLDIR/help}" >>$WINI
		echo "HTML	/	$WEBDIR" >>$WINI
		chmod 644 $WINI
	fi

}

#
# createWebGuiIni: Create $INSTALLDIR/udataobj/webgui/webgui.ini file for use
# with the web GUI.
#

createWebGuiIni()
{

	if [ -d "$INSTALLDIR" -a -d "$WEBDIR" ] ; then
		WINI=$INSTALLDIR/udataobj/webgui/webgui.ini
		echo "# Web GUI initialization file." >$WINI
		echo "# Created `date` by BEA software installation program." >>$WINI
		echo "#" >>$WINI
		echo "TUXDIR=$INSTALLDIR" >>$WINI
		echo "INIFILE=$INSTALLDIR/udataobj/webgui/webgui.ini" >>$WINI
		echo "NADDR=//`uname -n`:4003" >>$WINI
		if [ -r /dev/tcp ] ; then
			echo "DEVICE=/dev/tcp" >>$WINI
		else
			if [ -r /dev/inet/tcp ] ; then
				echo "DEVICE=/dev/inet/tcp" >>$WINI
			else
				if [ -r /dev/it ] ; then
					echo "DEVICE=/dev/it" >>$WINI
				else
					if [ -r /dev/streams/xtiso/tcp ] ; then
						echo "DEVICE=/dev/streams/xtiso/tcp" >>$WINI
					else
						if [ -r /patches/tcp ] ; then
							echo "DEVICE=/patches/tcp" >>$WINI
						fi
					fi
				fi
			fi
		fi
		echo "CODEBASE=/java" >>$WINI
		echo "DOCBASE=/doc" >>$WINI
		echo "SNAPDIR=$WEBJAVADIR/snapshot" >>$WINI
		echo "SNAPBASE=/java/snapshot" >>$WINI
		echo "#" >>$WINI
		echo "# In order to configure one or more domains as part of the Web GUI pull-down" >>$WINI
		echo "# menu, add lines to this file of the form DOMAIN=domainname;tuxconfig" >>$WINI
		echo "" >>$WINI
		chmod 644 $WINI
	fi

}

#
# createWLEenvfile: Create wle.env file containing useful environment variable
# settings
#

createWLEenvfile()
{
	#
	# If the environment file has already been created, we don't need it again.
	#
	if [ "$NEED_ENVFILE" != yes ] ; then
		return 0
	fi

	WLEENVFILE=$1/wle.env
	if [ -f "$WLEENVFILE" ] ; then
		chmod u+w $WLEENVFILE 2>/dev/null || return
		if [ ! -w "$WLEENVFILE" ] ; then
			return
		fi
	fi

	case "$PKG" in
	wletsrv|wletcli|wlecsrv|wleccli|wlejsrv|wlejcli|wlej2ee|wlermi)
		cat <<! >> $WLEENVFILE
TUXDIR=$INSTALLDIR; export TUXDIR
PATH=\$TUXDIR/bin:\$PATH; export PATH
COBCPY=:\$TUXDIR/cobinclude; export COBCPY
COBOPT="-C ANS85 -C ALIGN=8 -C NOIBMCOMP -C TRUNC=ANSI -C OSEXT=cbl"; export COBOPT
!
		if [ -f $INSTALLDIR/lib/libgp.so* -o -f $INSTALLDIR/lib/libgp.sl -o -n "$_TMLDPATH" ] ; then
			if [ -z "$_TMLDPATH" ] ; then
				_TMLDPATH=LD_LIBRARY_PATH
			fi
			cat <<! >> $WLEENVFILE
$_TMLDPATH=\$TUXDIR/lib:\$$_TMLDPATH; export $_TMLDPATH
!
		fi
		NEED_ENVFILE=no
		;;
	admcon)
                cat <<! >> $WLEENVFILE
WEBJAVADIR=$WEBJAVADIR
!
		NEED_ENVFILE=no
		;;

	esac

}

#
# Function which prompts for the tlisten password.
# setTlistenPwd Asumptions
# o Assumes that INSTALLDIR/udataobj exists.
# o Assumes that the system umask is set properly 600
#
setTlistenPwd()
{
	#
	# If the tlisten password has already been set, we don't need it again.
	# Remove the binary so there is no security risk.
	#
	if [ "$NEED_TLPWD" != yes ] ; then
		rm -f $INSTALLDIR/bin/tlistpwd
		return 0
	fi

	Prompt_User_yn "\nInstall tlisten password?"
	if [ $? != 0 ] ; then
		return 0
	fi
	#
	# udataobj must exist.
	#
	if [ ! -d $INSTALLDIR/udataobj ] ; then
		echo "\nERROR: Invalid target directory..." >&2
		doExit 1
	fi

	#
	# Run the utility which prompts for the tlisten
	# password. Set the library path since tlistpwd
	# makes use of shared libraries.
	#
	echo >&2
	eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/tlistpwd $INSTALLDIR

	if [ $? != 0 ] ; then
		echo "\nERROR: Cannot install tlistener password." >&2
		doExit 1
	fi

	#
	# Permissions should be 600 on the password file.
	# and the password utility should be removed after
	# it is used. Set the variable that tells us we don't
	# need to prompt for it again later.
               #              
	chmod 600 $INSTALLDIR/udataobj/tlisten.pw
	rm -f $INSTALLDIR/bin/tlistpwd  
	NEED_TLPWD=no

}

#
# createTUXlicFile: Create default empty $INSTALLDIR/udataobj/lic.txt file.
#

createTUXlicFile()
{

	# Tell the user what we are doing
	echo
	echo "Processing default license file..." >&2

	#
	# Determine whether or not the license file exists.  If it does, don't
	# do anything.  If it does not, create it and populate it with information.
	#
	LIC=$INSTALLDIR/udataobj/lic.txt
	if [ -f "$LIC" ] ; then
		return 0
	fi
	echo "# BEA license file" >$LIC
	echo "" >>$LIC
	echo "# This file contains license tokens to enable WebLogic Enterprise and optional components." >>$LIC
	echo "# Each license begins with \"[section name]\" and ends with a \"SIGNATURE=\" line." >>$LIC
	echo "# New license sections should be appended to this file, and the old section," >>$LIC
	echo "# if present, should be deleted." >>$LIC
	echo "" >>$LIC
	echo "# WARNING: altering parameters within a section will invalidate the license." >>$LIC
	echo "# This is a violation of BEA System's licensing agreement, and also may" >>$LIC
	echo "# disable WebLogic Enterprise or optional components." >>$LIC
	echo "" >>$LIC
	echo "# For technical support or to obtain a license, call 888-BEA-SUPT" >>$LIC
	echo "# (888-232-7878) or 408-743-4070." >>$LIC

	chmod 644 $LIC
	echo "... finished" >&2

}

#
# remindLicMsg: Display reminder to copy license file from floppy.
#

remindLicMsg()
{

	echo "\nPlease don't forget to manually copy the contents of the license file" >&2
	echo "from the enclosed floppy to '$INSTALLDIR/udataobj/lic.txt'." >&2
	echo "Refer to the BEA WLE Installation Guide for details on how to do this.\n" >&2

}

#
# remindLicUtilMsg: Display reminder to use lic.sh to
# 	 	    copy license file from floppy.
#

remindLicUtilMsg()
{


	echo "\nPlease don't forget to use lic.sh located in your product bin directory" >&2
	echo "to install the license file from the enclosed floppy." >&2
	echo "Refer to your product Installation Guide for details on how to do this.\n" >&2

}

#
# Pre-installation function for Tuxedo server personality.
#
preinstallwletsrv()
{

	CLASSES=$PKG

	#
	# If the installation directory has not been provided yet, prompt for it.
	#
	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	#
	# If server media intact, and server install initiate reinstall logic
	#
        if [ -f $INSTALLDIR/.wletsrvsuminfo ] ; then
                if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wletsrvsuminfo`" = "WebLogic5.1" ] ; then
			# prior server install detected, verify the files
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wletsrvsuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for Tuxedo server personality.
#
postinstallwletsrv()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Send license reminder, then bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
		if [ $? = 0 ] ; then
			INSTTARGDIR=$INSTALLDIR
			export INSTTARGDIR
			sh $INSTALLDIR/bin/lic.sh
		else
			remindLicUtilMsg
		fi
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.wletsrvsuminfo 

	changeBEAPerms $INSTALLDIR/.wletsrvsuminfo

	createTUXlicFile
	setTlistenPwd

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wletsrvsuminfo
	ckInstStatus
	
	Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
	if [ $? = 0 ] ; then
		INSTTARGDIR=$INSTALLDIR
		export INSTTARGDIR
		sh $INSTALLDIR/bin/lic.sh
	else
		remindLicUtilMsg
	fi

	return 0
}

#
# Pre-install function for Tuxedo client personality.
#
preinstallwletcli()
{

	WSONLY=yes
	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	if [ -f $INSTALLDIR/.wletclisuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wletclisuminfo`" = "WebLogic5.1" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wletclisuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-install function for Tuxedo client personality.
#
postinstallwletcli()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Send license reminder, then bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.wletclisuminfo 

	changeBEAPerms $INSTALLDIR/.wletclisuminfo

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wletclisuminfo
	ckInstStatus
	
	return 0
}

#
# Pre-installation function for CORBA C++ server personality.
#
preinstallwlecsrv()
{

	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	if [ -f $INSTALLDIR/.wlecsrvsuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlecsrvsuminfo`" = "WebLogic5.1" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wlecsrvsuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for CORBA C++ server personality.
#
postinstallwlecsrv()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Send license reminder, then bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
		if [ $? = 0 ] ; then
			INSTTARGDIR=$INSTALLDIR
			export INSTTARGDIR
			sh $INSTALLDIR/bin/lic.sh
		else
			remindLicUtilMsg
		fi
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.wlecsrvsuminfo 

	copySysReg

	registerplugin rli

	changeBEAPerms $INSTALLDIR/.wlecsrvsuminfo

	createTUXlicFile
	setTlistenPwd

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wlecsrvsuminfo
	ckInstStatus
	
	Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
	if [ $? = 0 ] ; then
		INSTTARGDIR=$INSTALLDIR
		export INSTTARGDIR
		sh $INSTALLDIR/bin/lic.sh
	else
		remindLicUtilMsg
	fi

	return 0
}

#
# Pre-installation function for CORBA C++ client personality.
#
preinstallwleccli()
{

	WSONLY=yes
	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	# Make sure we are not installing a client over a server.
	ckExistingServer

	if [ -f $INSTALLDIR/.wlecclisuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlecclisuminfo`" = "WebLogic5.1" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wlecclisuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for CORBA C++ client personality.
#
postinstallwleccli()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.wlecclisuminfo 

	copySysReg

	registerplugin rli

	changeBEAPerms $INSTALLDIR/.wlecclisuminfo

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wlecclisuminfo
	ckInstStatus
	
	return 0
}

#
# Pre-installation function for CORBA Java Server personality.
#
preinstallwlejsrv()
{

	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	if [ -f $INSTALLDIR/.wlejsrvsuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlejsrvsuminfo`" = "WebLogic5.1" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wlejsrvsuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for CORBA Java Server personality.
#
postinstallwlejsrv()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Send license reminder, then bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
		if [ $? = 0 ] ; then
			INSTTARGDIR=$INSTALLDIR
			export INSTTARGDIR
			sh $INSTALLDIR/bin/lic.sh
		else
			remindLicUtilMsg
		fi
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.wlejsrvsuminfo 

	copySysReg

	registerplugin rli

	changeBEAPerms $INSTALLDIR/.wlejsrvsuminfo

	createTUXlicFile
	setTlistenPwd

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wlejsrvsuminfo
	ckInstStatus
	
	Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
	if [ $? = 0 ] ; then
		INSTTARGDIR=$INSTALLDIR
		export INSTTARGDIR
		sh $INSTALLDIR/bin/lic.sh
	else
		remindLicUtilMsg
	fi

	return 0
}

#
# Pre-installation function for CORBA Java client personality.
#
preinstallwlejcli()
{

	WSONLY=yes
	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	# Make sure we are not installing a client over a server.
	ckExistingServer

	if [ -f $INSTALLDIR/.wlejclisuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlejclisuminfo`" = "WebLogic5.1" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wlejclisuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for CORBA Java client personality.
#
postinstallwlejcli()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.wlejclisuminfo 

	copySysReg

	registerplugin rli

	changeBEAPerms $INSTALLDIR/.wlejclisuminfo

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wlejclisuminfo
	ckInstStatus
	
	return 0
}

#
# Pre-installation function for RMI client personality.
#
preinstallwlermi()
{

	WSONLY=yes
	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	if [ -f $INSTALLDIR/.wlermisuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlermisuminfo`" = "WebLogic5.1" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wlermisuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for RMI client personality.
#
postinstallwlermi()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		return 0
	fi

	createWLEenvfile $INSTALLDIR

	createSuminfofile $INSTALLDIR/.wlermisuminfo 

	changeBEAPerms $INSTALLDIR/.wlermisuminfo

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wlermisuminfo
	ckInstStatus
	
	return 0
}

#
# Pre-installation function for WLE J2EE Server personality.
#
preinstallwlej2ee()
{

	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	if [ -f $INSTALLDIR/.wlej2eesuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlej2eesuminfo`" = "WebLogic5.1" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wlej2eesuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for WLE J2EE Server personality.
#
postinstallwlej2ee()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Send license reminder, then bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
		if [ $? = 0 ] ; then
			INSTTARGDIR=$INSTALLDIR
			export INSTTARGDIR
			sh $INSTALLDIR/bin/lic.sh
		else
			remindLicUtilMsg
		fi
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.wlej2eesuminfo 

	copySysReg

	registerplugin rli

	changeBEAPerms $INSTALLDIR/.wlej2eesuminfo

	createTUXlicFile
	setTlistenPwd

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wlej2eesuminfo
	ckInstStatus
	
	Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
	if [ $? = 0 ] ; then
		INSTTARGDIR=$INSTALLDIR
		export INSTTARGDIR
		sh $INSTALLDIR/bin/lic.sh
	else
		remindLicUtilMsg
	fi

	return 0
}

#
# Pre-installation function for Admin Console.
#
preinstalladmcon()
{

	CLASSES=$PKG

	if [ -z "$INSTALLDIR" ] ; then
		promptWLEDIR
	fi

	if [ -f $INSTALLDIR/.admconsuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $3 $5}' "$INSTALLDIR"/\.admconsuminfo`" = "AdministrationConsole5.1" ] ; then
			echo "\nChecking installed media..." >&2
			WEBJAVADIR=`grep WEBJAVADIR $INSTALLDIR/wle.env \
				2>/dev/null|\
			    sed s/WEBJAVADIR=//g` 
			export WEBJAVADIR
			verifyInst $INSTALLDIR/.admconsuminfo
			ckReinstStatus
		fi
	fi
	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.
	#
	if [ "$SKIPINST" = "no" ] ; then
		promptWEBDIR
		promptWEBJAVADIR
		promptWEBCGIDIR
		promptWEBCGIPREFIX
	fi

	return 0
}

#
# Post-installation function for Admin Console.
#
postinstalladmcon()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Send license reminder, then bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
		if [ $? = 0 ] ; then
			INSTTARGDIR=$INSTALLDIR
			export INSTTARGDIR
			sh $INSTALLDIR/bin/lic.sh
		else
			remindLicUtilMsg
		fi
		return 0
	fi

	createWLEenvfile $INSTALLDIR
	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`

	createSuminfofile $INSTALLDIR/.admconsuminfo 

	mvWebGuiFiles

	#
	# Permissions may be changed afer Web GUI File moves, since we use
	# variable path names for this component.
	# Note that:
	#  - Web GUI files may or may not be installed under INSTALLDIR;
	#  - files that may be modified by the adminstrator have perm 644;
	#  - tuxadm may or may not be in a directory with "bin" in the name
	#
	changeBEAPerms $INSTALLDIR/.admconsuminfo

	createTUXwsvrIni
	createWebGuiIni
	createTUXlicFile

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.admconsuminfo
	ckInstStatus
	
	Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
	if [ $? = 0 ] ; then
		INSTTARGDIR=$INSTALLDIR
		export INSTTARGDIR
		sh $INSTALLDIR/bin/lic.sh
	else
		remindLicUtilMsg
	fi

	return 0
}

#
# Pre-installation function for WLCS Online Doc.
#
preinstallwlcsdoc()
{

	CLASSES=$PKG

	promptWLCSDIR

	if [ -f $INSTALLDIR/.wlcsdocsuminfo ] ; then
		if [ "`awk 'NR == 1 {print $5 $6 $7}' "$INSTALLDIR"/\.wlcsdocsuminfo`" = "OnlineDocumentation2.0" ] ; then
			echo "\nChecking installed media..." >&2
			verifyInst $INSTALLDIR/.wlcsdocsuminfo
			ckReinstStatus
		fi
	fi

	return 0
}

#
# Post-installation function for WLCS Online Doc.
#
postinstallwlcsdoc()
{
	INSTALLMSGSENT="yes"

	#
	# SKIPINST = "yes" indicates a reinstall of same product/release with
	# successful verification of previously installed media.    
	# Bypass all postinstall logic via return.
	#
	if [ "$SKIPINST" = "yes" ] ; then
		return 0
	fi

	createSuminfofile $INSTALLDIR/.wlcsdocsuminfo 

	#
	# Change permissions so that files cannot be overwritten.
	#
	changeBEAPerms $INSTALLDIR/.wlcsdocsuminfo

	echo "\nVerifying installation..." >&2
	verifyInst $INSTALLDIR/.wlcsdocsuminfo
	ckInstStatus
	
	return 0
}

#
# Register the RLI plug-in
#
registerplugin()
{
	# Determine the suffix of the library based on platform.
	case $MNEMONIC in
	hp|HP)     sfx=".sl"
	;;
	sun5x|SUN5X|ibm|IBM)  sfx=".so.65"
	;;
	alpha|ALPHA|uw|UW)  sfx=".so"
	;;
	*)      sfx=".so"
	;;
	esac

	# Determine what we have to register and do it.
	case $1 in
	rli)
		echo "\nRegistering RLI plug-in..." >&2
		chmod 666 $INSTALLDIR/udataobj/System.rdp 2>/dev/null
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -i bea/pif/registry -p bea/wle -v 1.0 -f orbrlireg$sfx
		echo "... finished" >&2

		echo "\nRegistering Security plug-in..." >&2
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -i engine/security/authentication -p security/BEA/WLE_authentication -v 1.0 -f libwlesys$sfx -e _ep_dl_atnsvr
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -i engine/security/map_file -p security/BEA/WLE_map_file -v 1.0 -f libwlesys$sfx -e _ep_dl_mapfile
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -i engine/security/auditing -p security/BEA/WLE_audit_fan -v 1.0 -f libwlesys$sfx -e _ep_dl_audfan -s FANOUT:security/BEA/WLE_auditing
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -i engine/security/auditing -p security/BEA/WLE_auditing -v 1.0 -f libwlesys$sfx -e _ep_dl_audulog
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -i engine/security/authorization -p security/BEA/WLE_authorization_fan -v 1.0 -f libwlesys$sfx -e _ep_dl_atzfan -s FANOUT:security/BEA/WLE_authorization
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -i engine/security/authorization -p security/BEA/WLE_authorization -v 1.0 -f libwlesys$sfx -e _ep_dl_atzsvr
		echo "... finished" >&2
	;;
	security)
		echo "\nRegistering SSL plug-in..." >&2
		chmod 666 $INSTALLDIR/udataobj/System.rdp 2>/dev/null
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -p security/BEA/WLE_proof_mapper -i engine/security/map_proof -v 1.0 -f libwlesys$sfx -e _ep_dl_mapproof
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -p security/BEA/WLE_key_management -i engine/security/key_management -v 1.0 -f libwlesec$sfx -e _ec_sec_key_instantiate -u privateKeyDir=file://$INSTALLDIR/udataobj/security/keys
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -p security/BEA/WLE_certificate_parser -i engine/security/certificate_parsing -v 1.0 -f libwlesec$sfx -e _ec_sec_prs_instantiate -u principalIdentityField=13 -u issuerIdentityField=22
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -p security/BEA/WLE_certificate_validation -i engine/security/certificate_validation -v 1.0 -f libwlesec$sfx -e _ec_sec_val_instantiate -u caCertificateFile=file://$INSTALLDIR/udataobj/security/certs/trust_ca.cer -u peerValidationRuleFile=file://$INSTALLDIR/udataobj/security/certs/peer_val.rul
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -p security/BEA/WLE_combo_certificate_lookup -i engine/security/certificate_lookup -v 1.0 -f libwlesec$sfx -e _ep_dl_certlookup -u userCertificateLdap=ldap://$LDAPURL/ -u filterFileLocation=$LDAPFILTER -u ldapBaseObject=$LDAPBASEOBJ
		eval $_TMLDPATH=$INSTALLDIR/lib $INSTALLDIR/bin/epifreg -r -p bea/pkifile -i engine/security/pk_initialization -v 1.0 -f libwlesys$sfx -e _ep_dl_pkifile -s FANOUT
        echo "... finished" >&2
	;;
	esac

}

#
# Used to determine the location of the JOLT client files.
#
promptJOLTDIR()
{


	echo "\nThe client software should be installed either on your web" >&2
	echo "server machine, or a machine easily accessible to your web" >&2
	echo "server machine, as the class files must be downloaded." >&2
	echo "\nJOLTDIR below refers to the directory in which your java" >&2
	echo "releted files are stored.  It is the directory which contains" >&2
	echo "the directory 'classes', not the classes directory itself!\n" >&2

	while true ; do
	
		ANSWER=`ckpath -a \
			-d "$TUXDIR/udataobj/jolt" \
			-p "JOLTDIR" \
			-h "Consult your JOLT documentation for an appropriate directory"` || doExit $?
	
		valDIR "$ANSWER"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	# Pick up dir, since it may be different from ANSWER
	JOLTDIR=$dir
	mkdir $JOLTDIR >/dev/null 2>&1
	echo "\nUsing $JOLTDIR as the JOLT client tree" >&2

	#
	# If installing client only, make INSTALLDIR point to JOLTDIR. 
	# INSTALLDIR is the directory into which the installation is done.
	# If we are installing both client and server, the installation
	# directory, INSTALLDIR, should not be changed here. All files will be
	# installed into TUXDIR and the client files will have to be
	# moved.
	#
	if [ "${WSONLY}" = yes ]; then
		INSTALLDIR=$JOLTDIR
	fi
}

#
# Routines taken from Jolt's initial installation script used during
# the pre and postinstallation of BEA Jolt.
#
uninstallJoltServer ( ) {
        if [ -x $TUXDIR/joltsrv/uninstall ]
        then
                cd $TUXDIR/joltsrv
                echo "Uninstalling server files..."
                ./uninstall
                echo "Server files uninstalled."
        fi
        exit
}

ask () {

        echo
        echo $1 "($2)"
        eval val=$`eval echo $2`
        echo
        echo The default reply is:  $val
        echo Enter the new value for $2, or press
        echo the ENTER key to accept the default
        echo
        read answer
        case $answer in
                '?')    echo "Enter the new value for $2 or press enter "
                        echo "to accept the current value"
                        ;;
                '')     echo $2=`eval echo $"$2"`
                        ;;
                *)      eval "$2=$answer"
                        ;;
        esac
}

askyn () {
        echo
        echo $1 '[yes/no]'
        while [ 1 ]
        do
                read answer
                case $answer in
                        [Yy]*)  eval "$2=1"
                                return 1
                                ;;
                        [Nn]*)  eval "$2=0"
                                return 0
                                ;;
                        *)      echo "you must answer yes or no"
                                ;;
                esac
        done
}

checkTuxVersion () {
        release="`grep release $TUXDIR/.serialnumber 2>/dev/null`"
        tryanyway=1
        case "$release" in
                *6.1*)          ;;
                *6.2*)          ;;

                *Release*)      echo "The directory you have specified for"
                                echo "TUXDIR is $TUXDIR, and appears to have"
                                echo "a version of Tuxedo other than 6.1 or 6.2"
                                echo "Please note that Jolt 1.0.1 is supported"
                                echo "only on Tuxedo 6.1 and 6.2.  "
                                askyn "Do you want to try anyway?" tryanyway
                                ;;

                *)              echo "The directory you have specified for"
                                echo "TUXDIR is $TUXDIR, and appears to "
                                echo "not be a Tuxedo directory.  Installing"
                                echo "Jolt into a directory other than a"
                                echo "Tuxedo 6.1 or 6.2 directory is done at"
                                echo "your own risk, and should not be attempted
"
                                echo "unless supervised by BEA personnel."
                                echo " "
                                askyn "Do you want to try anyway?" tryanyway
                                ;;
        esac

        if [ $tryanyway = 0 ]; then
                eval "$1=0"
        else
                eval "$1=1"
        fi
}

promptLicense()
{
        pat='[0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9][0-9]'
        SERIAL=`ckstr -r "$pat" -l 10 \
                -h "The 10-digit serial number appears on the license informatio
n card" \
                -e "Invalid serial number; must have 10 digits" \
                -p "Jolt serial number"` || doExit $?

        x='[0-9A-Fa-f]'
        TOKEN=`ckstr -r "$pat" -l 16 \
                -h "The 16-character license token appears on the license information sheet" \
                -e "Invalid license token; must have 16 hexadecimal characters" \
                -p "Jolt license token"` || doExit $?
}

#
# valLicense: validate the license token, given SERIAL, TOKEN, TUXDIR, JOLTTYPE.
# Reprompt if necessary.
#
valLicense()
{

        if [ -z "$SERIAL" -o -z "$TOKEN" -o -z "$TUXDIR" -o -z "$JOLTTYPE" ]; then
                echo "ERROR: Internal error" >&2
                echo "Please contact customer support for assistance" >&2
                doExit 3
        fi

        if [ ! -x "$JOUTIL" ] ; then
                echo "ERROR: Internal error (no joutil)" >&2
                echo "Please contact customer support for assistance" >&2
                doExit 3
        fi

        while true ; do                                                        

                $JOUTIL -V -l "$TOKEN" -s "$SERIAL" -T "$JOLTTYPE" 2>/dev/null

                if [ "$?" -eq 0 ] ; then
                        break
                fi
                echo "ERROR: The license token <$TOKEN> and/or serial number <$SERIAL>" >&2
                echo "is invalid.  Please enter these again" >&2
                promptLicense
        done
}

#
# activateLicense: validate and burn in the license in the installed binaries.
# JOUTIL, TUXDIR, TOKEN, SERIAL, JOLTTYPE must be set.
#
activateLicense ( )
{

        valLicense

        echo "Activating the license for JOLT software in $TUXDIR ..." >&2
        $JOUTIL -b -r "$TUXDIR" -l "$TOKEN" -s "$SERIAL" -T "$JOLTTYPE" > /dev/null
        if [ $? -ne 0 ] ; then
                echo "ERROR: Unable to activate the license for this installation" >&2
                echo "Please contact customer support for assistance" >&2
                doExit 3
        fi
        echo "... finished" >&2
}

#
# The jolt client files go in JOLTDIR as opposed to TUXDIR.
mvJoltClientFiles()
{

	#
	# Make sure the client directory exists (it was installed) and
	# that the new location has been set (JOLTDIR).
	#
	if [ -d $TUXDIR/client -a x$JOLTDIR != x ]; then

		echo
		echo "Moving JOLT client files to their proper location..." >&2
		cd $TUXDIR/client

		#
		# Make JOLTDIR if it doesn't exist.
		#
		if [ ! -d `dirname $JOLTDIR` ]; then
			mkdir `dirname $JOLTDIR` ]
		fi

		if [ ! -d $JOLTDIR ]; then
			mkdir $JOLTDIR
		fi

		cp -f . $JOLTDIR
		cd $TUXDIR
		rm -rf $TUXDIR/client

		echo "... finished" >&2
	
	fi
}
	

promptTUXDIR_forJOLT()
{

	while true ; do

		ANSWER=`ckpath -a \
			-p "TUXDIR" \
			-h "Specify a directory for the Tuxedo base directory"` || doExit $?

		valDIR "$ANSWER"
		if [ "$?" -eq 0 ] ; then
			break
		fi
	done

	#
	# libgp.a is installed on every Tuxedo platform.
	#
	if [ ! -f "$ANSWER/lib/libgp.a" ]; then
		echo "\nERROR: $ANSWER doesn't contain a valid Tuxedo installation.\n" >&2
		doExit 1
	fi

	# Pick up dir, since it may be different from ANSWER
	INSTALLDIR=$dir
	echo "\nUsing $INSTALLDIR as the Tuxedo base directory" >&2
}

promptJOLTOpts()
{

	ANSWER=`ckitem -l "The following installation options are available:" \
		-p "Select an option" \
		-d "both" \
		"both	Install the full JOLT System - client and server" \
		"client	Install the client only"` || doExit $?

	# Make sure correct CLASSES are known to checkSPACE
	case "$ANSWER" in
	both)	CLASSES='wsc'
		;;
	client)	WSONLY=yes
		CLASSES='ws'
		;;
	*)	doExit 1
		;;
	esac

}

#
# BEA Jolt's pre-installation routine.
#
requestjolt()
{

	WSONLY=
	TUXDIR=
	INSTALLDIR=
	
	#
	# This function will set the WSONLY and CLASSES 
	# variables. WSONLY means install the client only,
	# CLASSES is used to determine which of the cpio
	# files containing JOLT to install.
	#
	promptJOLTOpts

	#
	# If client only is selected, no reason to show this message.
	#
	if [ "$WSONLY" != yes ]; then
		trap "uninstallJoltServer" 1 2 3 15
        	echo "\nNote that the jolt server will be installed into an existing" >&2
        	echo "Tuxedo directory.  You MUST have previously installed Tuxedo" >&2
        	echo "version 6.1 or 6.2 to attempt this installation." >&2
        	echo >&2

		promptTUXDIR_forJOLT
	fi

	#
	# Jolt server files go into an existing TUXDIR, the client 
	# files may go into JOLTDIR. If the customer is 
	# installing client only, do not prompt for TUXDIR. If the 
	# customer is installing both client and server, prompt for
	# both TUXDIR and JOLTDIR.
	#
	promptJOLTDIR
	return 0
}

postinstalljolt()
{

	#
	# Prompt for license information if installing
	# Jolt server.
	#
	if [ "$WSONLY" != yes ]; then
		promptLicense
        	JOUTIL=$TUXDIR/bin/joutil
		echo "JOUTIL is $JOUTIL"
        	JOLTTYPE=SDK
        	activateLicense
	fi

	#
	# If this is a client only installation, the suminfo
	# file should be placed in JOLTDIR as opposed to TUXDIR,
	# since we don't know TUXDIRs location.
	#
	if [ "${WSONLY}" != yes ]; then
		createSuminfofile $TUXDIR/.joltsuminfo
		changeTUXPerms $TUXDIR/.joltsuminfo
		mvJoltClientFiles
	else
		createSuminfofile $JOLTDIR/.joltsuminfo
		changeTUXPerms $JOLTDIR/.joltsuminfo
	fi

	return 0
}

#
# BEA Connect's PRE-INSTALLATION SCRIPT for its TPS package.
#
requesttps()
{

	#
	# The classes variable must be set by the request
	# script so that the file that contains the package
	# is known.
	#
	CLASSES='tps'

	promptTPSDIR
	return 0
}

#
# BEA Connect's POST-INSTALLATION SCRIPT for its TPS package.
#
postinstalltps()
{

	createSuminfofile $INSTALLDIR/.tpssuminfo
	#
	# Can use Tuxedo's permissions function to make
	# sure the permissions are what we want on the files
	# installed.
	#
	changeTUXPerms $INSTALLDIR/.tpssuminfo
	return 0
}

#
# BEA Connect's PRE-INSTALLATION SCRIPT for its SNA package.
#
requestsna()
{

	#
	# The classes variable must be set by the request
	# script so that the file that contains the package
	# is known.
	#
	CLASSES='snabase snastk'
        if [ "$MNEMONIC" = "uw" ]; then
                checkUWVersion
        fi     

	promptSNAOpts
	promptSNADIR
	return 0
}

#
# BEA Connect's POST-INSTALLATION SCRIPT for its SNA package.
#
postinstallsna()
{

	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null` 
	createSuminfofile $INSTALLDIR/.snasuminfo
	#
	# Can use Tuxedo's permissions function to make
	# sure the permissions are what we want on the files
	# installed.
	#
	changeTUXPerms $INSTALLDIR/.snasuminfo
	#
	# Conditionally install license file based on user response.
	#
	Prompt_User_yn "\nIf your license file is accessible, you may install it now.\nInstall license file?"
	if [ $? = 0 ] ; then
		INSTTARGDIR=$INSTALLDIR
		export INSTTARGDIR
		sh $INSTALLDIR/bin/lic.sh
	else
		remindLicUtilMsg
	fi

	return 0
}

#
# BEA Connect's PRE-INSTALLATION SCRIPT for its OSI package.
#
requestosi()
{

	#
	# The classes variable must be set by the request
	# script so that the file that contains the package
	# is known.
	#
	CLASSES='osi'
        if [ "$MNEMONIC" = "uw" ]; then
                checkUWVersion
        fi        

	promptOSIDIR
	return 0
}

#
# BEA Connect's POST-INSTALLATION SCRIPT for its OSI package.
#
postinstallosi()
{

	newTUXLocale `find $INSTALLDIR/locale -type d -name C -print 2>/dev/null`
	createSuminfofile $INSTALLDIR/.osisuminfo
	#
	# Can use Tuxedo's permissions function to make
	# sure the permissions are what we want on the files
	# installed.
	#
	changeTUXPerms $INSTALLDIR/.osisuminfo
	remindLicMsg

	return 0
}

#
# BEA security service pre-install function.
#
preinstallsec56()
{

	#
	# Need a temp file.
	# 
	ENCTMP=/tmp/BEA3.$$
	> $ENCTMP

	#
	# Remember which package we are installing (indicates encryption strength).
	#
	ENCPKG=$PKG

	#
	# Having WLE installed is a prerequisite.
	#
	echo "\nWebLogic Enterprise must be installed prior to installing the Encryption Package" >&2

	#
	# Get the name of the directory in which to install the security package and
	# verify that it is in fact a valid WLE directory.
	# Then find out if the installation was Tuxedo-only or
	# not.  If it was, we just want to install the encryption portion of the
	# security package.  If it was not, install both encryption and SSL.
	#
	while true ; do

		getTUXDIR

		#
		# Tuxedo-only install will not contain any of these files in $TUXDIR.
		#
		if [ -f "$INSTALLDIR/.wlecsrvsuminfo" -o -f "$INSTALLDIR/.wlecclisuminfo" -o -f "$INSTALLDIR/.wlejsrvsuminfo" -o -f "$INSTALLDIR/.wlejclisuminfo" -o -f "$INSTALLDIR/.wlej2eesuminfo" ] ; then
			CLASSES="$PKG secssl"
			ENCONLY=
		else
			if [ -f "$INSTALLDIR/.wletsrvsuminfo" -o -f "$INSTALLDIR/.wletclisuminfo" ] ; then
				CLASSES=$PKG
				ENCONLY=yes
			else
				#
				# RMI client-only install does not have plugin registration
				# binaries, so don't allow the user to continue.
				#
				if [ -f "$INSTALLDIR/.wlermisuminfo" ] ; then
					echo "ERROR: Installed component does not support this add-on."
					exit 1
				fi
			fi
		fi

		#
		# Make sure there is enough space for this software.
		#
		checkSpace $INSTALLDIR
		if [ $? -eq 0 ] ; then
			break
		fi
	done

	#
	# Now that we have a valid WLE installation, verify the version of
	# the libgp file - we can only replace a file with the same version
	# as that of the one we are installing.
	#
	# IRIX doesn't have a 'what' command, so skip...
	#
	if [ `uname -s` != IRIX ]; then

		#
		# Use the 'what' command to find the string containing version info.
		#
		CURLEVEL=`what $INSTALLDIR/lib/$GPFILENAME | grep Port \
			  | sed -e 's/^[ 	]*//'`

		#
		# On AIX, the information returned by the 'what' command occurs twice
		# in the library.  Send this info to a file and look for what we want
		# there.
		#
		echo "$CURLEVEL" > $ENCTMP

		#
		# PORT comes from the pkginfo file.
		#
		NEWLEVEL=`echo $PORT`
		if [ `grep -c "$NEWLEVEL" $ENCTMP` = 0 ] ; then
			echo "ERROR: WLE version does not match security service version."
			rm -rf $ENCTMP
			doExit 1
		fi

		#
		# Determine the strength of encryption already installed.
		#
		CURCRYPT=`what $INSTALLDIR/lib/$GPFILENAME | grep -i encry | grep [0-9]`
		echo "$CURCRYPT" > $ENCTMP

		if [ `grep -c 128 $ENCTMP` != 0 ] ; then
			CURCRYPT=128
		elif [ `grep -c 56 $ENCTMP` != 0 ] ; then
			CURCRYPT=56
		elif [ `grep -c 0 $ENCTMP` != 0 ] ; then
			CURCRYPT=0
		else
			echo "\nERROR: Could not determine encryption level" >&2
			rm -rf $ENCTMP
			doExit 1
		fi
	else
		#
		# IRIX - set CURCRYPT to IRIX
		#
		CURCRYPT=IRIX
	fi

	rm -rf $ENCTMP

	#
	# Move the current libgp to a backup in case there is a problem.
	#
	echo "\nMoving $INSTALLDIR/lib/$GPFILENAME to $INSTALLDIR/lib/$GPFILENAME.$CURCRYPT" >&2

	mv $INSTALLDIR/lib/$GPFILENAME $INSTALLDIR/lib/$GPFILENAME.$CURCRYPT
	
	if [ "$?" -ne 0 ]; then
		echo "\nERROR: Cannot backup $GPFILENAME...an application may be running" >&2
		doExit 1
	fi

	#
	# If we are not running on AIX, we can move the current libgp.a
	# to a backup in case user reverts back to a previous encryption level.
	#
	if [ "$GPFILENAME" != "$GPFILENAMEA" ] ; then

		echo "\nMoving $INSTALLDIR/lib/$GPFILENAMEA to $INSTALLDIR/lib/$GPFILENAMEA.$CURCRYPT" >&2

		mv $INSTALLDIR/lib/$GPFILENAMEA $INSTALLDIR/lib/$GPFILENAMEA.$CURCRYPT
	
		if [ "$?" -ne 0 ]; then
			echo "\nERROR: Cannot backup $GPFILENAMEA...an application may be running" >&2
			doExit 1
		fi

	fi

	return 0
}

preinstallsec128()
{
	preinstallsec56
}

#
# BEA security service post-installation function.
#
postinstallsec56()
{

	#
	# If we are installing the SSL portion of the security service, prompt
	# the user for information to be used for registering the plugin.
	#
	if [ "$ENCONLY" != yes ] ; then
		#
		# Get the URL of the LDAP server computer system.
		#
		promptLDAPURL

		#
		# Get the location and name of the LDAP filter file.
		#
		promptLDAPFILTER

	fi

	#
	# If we are installing the SSL portion of the security service, create
	# a directory to hold private key files.
	#
	if [ "$ENCONLY" != yes ] ; then
		mkdir -p $INSTALLDIR/udataobj/security/keys 2>/dev/null
	fi

	#
	# Create the suminfo file.  If the SSL portion of the security service
	# package is being installed, concatenate the list of its files to the
	# end of it.
	#
	if [ "$ENCPKG" = sec56 ]; then
		createSuminfofile $INSTALLDIR/.sec56suminfo
		if [ "$ENCONLY" != yes ] ; then
			cat `echo [Ss][Uu][Mm][Ii][Nn][Ff][Oo]1` >> $INSTALLDIR/.sec56suminfo
		fi
	else
		createSuminfofile $INSTALLDIR/.sec128suminfo
		if [ "$ENCONLY" != yes ] ; then
			cat `echo [Ss][Uu][Mm][Ii][Nn][Ff][Oo]1` >> $INSTALLDIR/.sec128suminfo
		fi
	fi

	#
	# If we are installing the SSL portion of the security service,
	# register the plugin.
	#
	if [ "$ENCONLY" != yes ] ; then
		#
		# The plugin registration function requires the _TMLDPATH variable
		# to be set.  On platforms where the shared library path variable
		# is not LD_LIBRARY_PATH (like HP-UX) this variable was set at the
		# beginning of the install.
		#
		if [ -z "$_TMLDPATH" ] ; then
			_TMLDPATH=LD_LIBRARY_PATH
		fi

		#
		# Register the SSL plugin.
		#
		registerplugin security

	fi

	#
	# Make sure the permissions on the new files are correct.
	#
	changeENCPerms

	return 0
}

postinstallsec128()
{
	postinstallsec56
}

requestjoltdoc()
{

	JOLTDOCDIR=
	CLASSES=joltdoc

	# WARNING: TUXDIR must be set
	promptJOLTDOCDIR $TUXDIR

	return 0

}

postinstalljoltdoc()
{

	createSuminfofile $JOLTDOCDIR/.joltdocsuminfo
	#
	# Make sure the permissions are what we want on the files
	# installed.
	#
	changeTUXPerms $JOLTDOCDIR/.joltdocsuminfo

	return 0
}

#
# Change file permissions.
# This is a generic function for any package that installs under
# the BEA-standard directory structure.  This differs from the
# predecessor function changeTUXPerms, in the deletion of $PRODUCTDIR
# as a part of the chmod target.  The suminfo structure has changed
# to include a variable directory prefix based on the product and
# particular component, e.g, Web Gui, being installed.
# 
# Takes the sum information filename as its only parameter. (full pathname)
#
changeBEAPerms()
{
 
	#
	# Make sure the sum information file is passed as a parameter.
	#
	if [ -z "$1"  ]; then
		echo "ERROR changeBEAPerms: sum information file not passed" >&2
                echo "Please contact customer support for assistance" >&2
                doExit 1 
	fi

	#
	# The sum information file must be readable.
	#
	SUMFILENAME=$1
	if [ ! -r "$SUMFILENAME"  ]; then
		echo "ERROR changeBEAPerms: The sum information file is not readable" >&2
                echo "Please contact customer support for assistance" >&2
                doExit 1 
	fi

	echo "\nChanging file permissions..." >&2
 
	#
	# Make directories 755, files in bin
	# and .sl files (on hp) in lib 555, udataobj/RM file 666,  
	# and all else 444.
	#
	for i in `grep '^[0-9]' < $SUMFILENAME | sed -e 's/.* //'`
	do
		case $i in
		*/bin/*|*/lib/*.sl)
			cmd="chmod 555 "$i" 2>/dev/null"
			eval $cmd
			;;
		*/udataobj/RM)
			cmd="chmod 666 "$i" 2>/dev/null"
			eval $cmd
			;;
		*)
			cmd="chmod 444 "$i" 2>/dev/null"
			eval $cmd
			;;
		esac
	done
 
	echo "... finished" >&2
}

#
# Change file permissions.
# This is a generic function for any package that installs under
# a TUXDIR-like directory structure
# 
# Takes the sum information filename as its only parameter. (full pathname)
#
changeTUXPerms()
{
 
	#
	# Make sure the sum information file is passed as a parameter.
	#
	if [ -z "$1"  ]; then
		echo "ERROR changeTUXPerms: sum information file not passed" >&2
                echo "Please contact customer support for assistance" >&2
                doExit 1 
	fi

	#
	# The sum information file must be readable.
	#
	SUMFILENAME=$1
	if [ ! -r "$SUMFILENAME"  ]; then
		echo "ERROR changeTUXPerms: The sum information file is not readable" >&2
                echo "Please contact customer support for assistance" >&2
                doExit 1 
	fi

	#
	# The assumption is that all the files we are changing
	# permissions on exist under the directory in which the
	# sum information file is contained.
	#
	PRODUCTDIR=`dirname $1`

	echo "\nChanging file permissions..." >&2
 
	#
	# Make directories 755, files in bin
	# and .sl files (on hp) in lib 555, and all else 444.
	#
	for i in `grep '^[0-9]' < $SUMFILENAME | sed -e 's/.* //'`
	do
		case $i in
		bin/*|lib/*.sl)
			chmod 555 $PRODUCTDIR/$i 2>/dev/null
			;;
		*)
			chmod 444 $PRODUCTDIR/$i 2>/dev/null
			;;
		esac
	done
 
	echo "... finished" >&2
}

#
# Change file permissions for the security libraries.
#
changeENCPerms()
{
 
	echo "\nChanging file permissions..." >&2
 
	#
	# Change permissions on lib/libgp files.
	# .sl files (on hp) need to be set to 555, all else are 444.
	#
	for i in `ls $INSTALLDIR/lib/libgp*`
	do
		case $i in
		*.sl)
			chmod 555 $i 2>/dev/null
			;;
		*)
			chmod 444 $i 2>/dev/null
			;;
		esac
	done
 
	echo "... finished" >&2
}

#
# Move web GUI HTML documents, Java scripts, and CGI programs to the
# directories specified by the user.
#
mvWebGuiFiles()
{

	if [ -f $INSTALLDIR/udataobj/webgui/webguitop.html ] ; then
		sed -e "s!http://HOST/CGI-BIN!$WEBCGIPREFIX!" \
		    -e "s!TUXDIRVALUE!$INSTALLDIR!" \
		    <$INSTALLDIR/udataobj/webgui/webguitop.html \
		    >$INSTALLDIR/udataobj/webgui/webguitop.tmp
		mv -f $INSTALLDIR/udataobj/webgui/webguitop.tmp \
		      $INSTALLDIR/udataobj/webgui/webguitop.html
	fi

	WEBMSG=n
	if [ -d $INSTALLDIR/udataobj/webgui -a x$WEBDIR != x -a x$WEBDIR != x$INSTALLDIR/udataobj/webgui ] ; then
		echo
		echo "Moving BEA Administration Console files to their proper location..." >&2
		WEBMSG=y
		cd $INSTALLDIR/udataobj/webgui
		if [ ! -d `dirname $WEBDIR` ]
		then
			mkdir -p `dirname $WEBDIR` ]
		fi
		if [ ! -d $WEBDIR ]
		then
			mkdir $WEBDIR
		fi
		cp -rf admconsole.jpg webguitop.html webgui.html $WEBDIR
		cd $INSTALLDIR
		chmod 644 $WEBDIR/admconsole.jpg $WEBDIR/webguitop.html $WEBDIR/webgui.html
	fi

	if [ -d $INSTALLDIR/web/gui/java -a x$WEBJAVADIR != x -a x$WEBJAVADIR != x$INSTALLDIR/web/gui/java ]
	then
		if [ $WEBMSG = n ]
		then
			echo
			echo "Moving BEA Administration Console files to their proper location..." >&2
			WEBMSG=y
		fi
		cd $INSTALLDIR/web/gui/java
		if [ ! -d $WEBJAVADIR ]
		then
			mkdir -p $WEBJAVADIR
		fi
		cp -Rf . $WEBJAVADIR
		cd $INSTALLDIR
		rm -rf $INSTALLDIR/web/gui/java
	fi

	if [ -d $INSTALLDIR/bin -a x$WEBCGIDIR != x -a x$WEBCGIDIR != x$INSTALLDIR/bin ]
	then
		if [ $WEBMSG = n ]
		then
			echo
			echo "Moving BEA Administration Console files to their proper location..." >&2
			WEBMSG=y
		fi
		if [ ! -d $WEBCGIDIR ]
		then
			mkdir -p $WEBCGIDIR
		fi
		cp -f $INSTALLDIR/bin/tuxadm $WEBCGIDIR/tuxadm
		chmod 555 $WEBCGIDIR/tuxadm
	fi
	
	if [ $WEBMSG = y ]
	then
		echo "... finished" >&2
	fi

	# Remove original web directories if they are now empty.
	if [ -d $INSTALLDIR/web/gui -a "x`cd $INSTALLDIR/web/gui; echo *`" = 'x*' ]
	then
		rmdir $INSTALLDIR/web/gui
	fi
	if [ -d $INSTALLDIR/web -a "x`cd $INSTALLDIR/web; echo *`" = 'x*' ]
	then
		rmdir $INSTALLDIR/web
	fi
}

#
# Create System Registry for ORB from appropriate template, based on
# type of install (Both or Client-Only).  Copy, rather than move file
# so subsequent install verifications won't fail.
#
copySysReg()
{
	if [ "$WSONLY" = yes ] ; then
		if [ -f $INSTALLDIR/udataobj/SysRegiiop.rdp ] ; then
			cp -f $INSTALLDIR/udataobj/SysRegiiop.rdp \
				$INSTALLDIR/udataobj/System.rdp 2>/dev/null 
		fi
	else
		if [ -f $INSTALLDIR/udataobj/SysRegtgiop.rdp ] ; then
			cp -f $INSTALLDIR/udataobj/SysRegtgiop.rdp \
				$INSTALLDIR/udataobj/System.rdp 2>/dev/null 
		fi
	fi
}

#
# This function performs checksum on all files listed in $suminfofilename,
# comparing result to sum in $suminfofilename.  Failures are logged in
# install.log.
#
verifyInst()
{
	SUMEXEC=$INSTALLDIR/sumexec.sh
	INSTALLRESULT=
	SUMINFOFILENAME=$1

	#
	# Make sure there is a sum command on this
	# platform.
	#
	FOUND_SUM="`type sum | grep ' is '`"
 
	if [ -n "${FOUND_SUM}" ] ; then
		#
		# Create shell script to execute checksum on files contained
		# in $SUMINFOFILENAME.
		#
		awk 'BEGIN {count=0}

		{ if (count > 1) { 
			print "if [ ! -f "$3" ] ; then echo "$3" \"... file not found\" ;  fi 2>/dev/null" 
			print "if [ `sum "$3"|cut -d\" \" -f1` != "$1" ] ; then echo "$3" \"... checksum failed\" ;  fi 2>/dev/null" }
		} 

		{ if ($1 == "") count+=1 }

		' TUXDIR=$INSTALLDIR $SUMINFOFILENAME > $SUMEXEC  

		sh $SUMEXEC > $INSTALLDIR/install.log
		rm -f $SUMEXEC 2>/dev/null
	else
		echo "\nNo sum command available...\n" >&2
	fi
}

#
# This function generates success/failure message based on result of 
# checksum compare on all installed files performed in verifyInst().  
#
ckInstStatus()
{
	INSTALLRESULT=`wc -w $INSTALLDIR/install.log|awk '{print $1}'`
	if [ $INSTALLRESULT = 0 ] ; then
		echo "... Installation successful!\n"
		rm -f $INSTALLDIR/install.log 2>/dev/null
	else
		echo "Errors were encountered during install verification."
		echo "Check install.log in your install target directory for details.\n"
	fi                                   	
}

#
# This function sets SKIPINST flag based on result of checksum compare on 
# all installed files performed in verifyInst(). If all files are present
# then we can skip most of the installation logic.
#
ckReinstStatus()
{
	INSTALLRESULT=`wc -w $INSTALLDIR/install.log|awk '{print $1}'`
	if [ $INSTALLRESULT = 0 ] ; then
		SKIPINST="yes"
	else
		SKIPINST="no"
	fi                                   	

	rm -f $INSTALLDIR/install.log 2>/dev/null
}

#
#
# This function looks for a server installation in the chosen directory. 
# If it finds one and it is the current version, the install terminates.
#
ckExistingServer()
{

	# C++ server.
	if [ -f $INSTALLDIR/.wlecsrvsuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlecsrvsuminfo`" = "WebLogic5.1" ] ; then
			echo "\nA prior installation of the WebLogic Enterprise C++ Server software" >&2
			echo "has been detected in this directory." >&2
			echo "\nTo install this client in this directory, you must first remove the" >&2
			echo "existing system." >&2
			doExit 1
		fi
	fi

	# Java server.
	if [ -f $INSTALLDIR/.wlejsrvsuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlejsrvsuminfo`" = "WebLogic5.1" ] ; then
			echo "\nA prior installation of the WebLogic Enterprise Java Server software" >&2
			echo "has been detected in this directory." >&2
			echo "\nTo install this client in this directory, you must first remove the" >&2
			echo "existing system." >&2
			doExit 1
		fi
	fi

	# J2EE server.
	if [ -f $INSTALLDIR/.wlej2eesuminfo ] ; then
		if [ "`awk 'NR == 1 {print $2 $5}' "$INSTALLDIR"/\.wlej2eesuminfo`" = "WebLogic5.1" ] ; then
			echo "\nA prior installation of the WebLogic Enterprise J2EE Server software" >&2
			echo "has been detected in this directory." >&2
			echo "\nTo install this client in this directory, you must first remove the" >&2
			echo "existing system." >&2
			doExit 1
		fi
	fi

}

# This function goes through the list of platforms returned in the 
# $RAWPLATFORMLIST variable and creates a user-friendly version
# in $NICEPLATFORMLIST.
#
bldPlatformMenu()
{

	#
	# If we already created the list, don't do it again.
	#
	if [ -n "$NICEPLATFORMLIST" ] ; then
		return 0
	fi

	idx=0

	for p in $RAWPLATFORMLIST ; do

		idx=`expr $idx + 1 2>/dev/null`

		case "$p" in
		aldux40|ALDUX40)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tCompaq Tru64 UNIX v4.0f\n" ;;
		pahp1100|PAHP1100)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tHP-UX v11.00\n" ;;
		ppaix433|PPAIX433)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tIBM AIX v4.3.3\n" ;;
		spsol26|SPSOL26)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tSun Solaris v2.6\n" ;;
		spsol7|SPSOL7)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tSun Solaris 7\n" ;;
		insco504|INSCO504)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tSCO Unix v5.0.4\n" ;;
		inuw71|INUW71)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tSCO UnixWare v7.1\n" ;;
		inmpr302|INMPR302)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tNCR MP-RAS v3.0.2\n" ;;
		inseq442|INSEQ442)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tSequent DYNIX/ptx v4.4.2\n" ;;
		inseq444|INSEQ444)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tSequent DYNIX/ptx v4.4.4\n" ;;
		mpirx65|MPIRX65)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tSGI IRIX v6.5\n" ;;
		uss390r6|USS390R6)
			NICEPLATFORMLIST="$NICEPLATFORMLIST\t$idx)\tIBM OS/390 Unix System Services R6\n" ;;
		esac

	done

}


#
# MAIN PROCESSING
#
umask 022
# clear the screen
clear 2>/dev/null
beginMsg
trap "echo '\nInstallation terminated' >&2; exit 0" 2 15
RAWPLATFORMLIST=
NICEPLATFORMLIST=

getplatforms

a=`echo "$RAWPLATFORMLIST" | wc -l | sed -e 's/.*[ 	]//'`
if [ "$a" = 1 ]
then
	ANSWER=$RAWPLATFORMLIST
	PLATFORM=$ANSWER
	DisplayChoice
else
	PresentPlatforms
	GetPlatformNumber
	ConvertNumberToDirectory
	DisplayChoice
	#
	# Confirm the selection.
	#
	ANSWER=
	while [ -z "${ANSWER}" ]; do

		echo "Is this correct? [y,n,q]: \c" >&2
		read ANSWER

        	case "${ANSWER}" in
        	y|Y)
			#
			# Ok with selection. Continue with install.
			#
                	break
        	;;
		n|N)
			#
			# Not happy with selection - give the user
			# another chance.
			#
			PresentPlatforms
			GetPlatformNumber
			ConvertNumberToDirectory
			DisplayChoice
			ANSWER=
		;;
        	q|Q)
			doExit 0
        	;;
        	*) 
			# 
			# Not y, n or q. Ask again.
			#
			ANSWER=
        	;;         
		esac
	done
fi

#
# Set the environment for the installation process based
# on the MNEMONIC.
#
MNEMONIC=`echo ${PLATFORM} | awk -F/ '{print $1}'`

case "${MNEMONIC}" in
aldux40|ALDUX40)
	envAlpha
;;
pahp1020|PAHP1020|pahp1100|PAHP1100)
	envHp
;;
ppaix433|PPAIX433)
	envIbm
;;
inmpr302|INMPR302)
	envNcr
;;
insco504|INSCO504)
	envSco
;;
inseq442|INSEQ442|inseq444|INSEQ444)
	envSeq
;;
mpirx65|MPIRX65)
	envSgi
;;
spsol251|SPSOL251|spsol26|SPSOL26|spsol7|SPSOL7)
	envSun5x
;;
inuw71|INUW71)
	envUw
;;
*)
	envGeneric
;;
esac

#
# The root of the cd.
#
CDROOT=`pwd`

#
# Go to the installation directory of choice and
# execute the main processing loop.
#
cd $PLATFORM

export PATH
#
# Tell how to quit
#
echo "\nTo terminate the installation at any time" >&2
echo "press the interrupt key," >&2
echo "typically <del>, <break>, or <ctrl+c>." >&2
WSONLY=
SKIPINST="no"
STACKSEL=
INSTALLDIR=
NEED_TLPWD=yes
NEED_ENVFILE=yes
MAXPKGS=0
NUMPKGS=0
#
# Main processing
#
while [ true ] ; do
	promptComponents || doExit $?
	promptPkgs || doExit $?
	MAXPKGS=`echo "$PKGS"|wc -w`
	installPkgs || doExit $?
	if [ -n "$ALLPKGS" ] ; then
		break
	fi
	NUMPKGS=`expr $NUMPKGS + 1 2>/dev/null`
	if [ $NUMPKGS = $MAXPKGS ] ; then
		break
	fi
done

exit 0
